AndroidViewConfiguration class

Android-specific viewer configuration options.

Use this class for options that only apply to the Android platform. Pass an instance as NutrientViewConfiguration.androidConfig.

All fields are optional. Unset fields (null) use the Nutrient Android SDK's built-in defaults.

Example

NutrientViewConfiguration(
  androidConfig: AndroidViewConfiguration(
    grayScale: false,
    showSearchAction: true,
    showOutlineAction: true,
    showBookmarksAction: false,
    inlineSearch: true,
    enableDocumentEditor: true,
    darkThemeResource: 'MyDarkTheme',
  ),
)

Platform availability

All fields on this class are Android-only. On iOS and Web they are silently ignored.

Constructors

AndroidViewConfiguration({bool? grayScale, AppearanceMode? appearanceMode, ThumbnailBarMode? thumbnailBarMode, bool? showPageLabels, bool? documentLabelEnabled, bool? inlineSearch, bool? showActionNavigationButtons, bool? showSearchAction, bool? showOutlineAction, bool? showBookmarksAction, bool? showAnnotationListAction, bool? showThumbnailGridAction, bool? showPrintAction, bool? enableDocumentEditor, bool? contentEditorEnabled, String? darkThemeResource, String? defaultThemeResource})
Creates an AndroidViewConfiguration.
const

Properties

appearanceMode → AppearanceMode?
The colour theme for the viewer.
final
contentEditorEnabled → bool?
Enable the content editing feature.
final
darkThemeResource → String?
Name of the Android XML theme resource to use for the dark colour scheme.
final
defaultThemeResource → String?
Name of the Android XML theme resource to use for the default (light) colour scheme.
final
documentLabelEnabled → bool?
Show the document title overlay at the top of the viewer.
final
enableDocumentEditor → bool?
Enable the document editor feature.
final
grayScale → bool?
Render the document in greyscale.
final
hashCode → int
The hash code for this object.
no setterinherited
inlineSearch → bool?
Use inline search instead of a full-screen search dialog.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showActionNavigationButtons → bool?
Show back/forward page-navigation buttons in the toolbar.
final
showAnnotationListAction → bool?
Show the annotation list action in the viewer toolbar.
final
showBookmarksAction → bool?
Show the bookmarks action in the viewer toolbar.
final
showOutlineAction → bool?
Show the outline (table of contents) action in the viewer toolbar.
final
showPageLabels → bool?
Show page labels instead of page numbers in the thumbnail bar and navigation.
final
showPrintAction → bool?
Show the print action in the viewer toolbar.
final
showSearchAction → bool?
Show the full-text search action button in the viewer toolbar.
final
showThumbnailGridAction → bool?
Show the thumbnail grid action in the viewer toolbar.
final
thumbnailBarMode → ThumbnailBarMode?
Where and how the thumbnail bar is displayed.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited