defaultThemeResource property

String? defaultThemeResource
final

Name of the Android XML theme resource to use for the default (light) colour scheme.

The string must match a theme declared in your Android app's res/values/ directory. This theme is applied when appearanceMode (or NutrientViewConfiguration.appearanceMode) is set to AppearanceMode.defaultMode or AppearanceMode.sepia.

Example: 'MyApp_Light' — the theme must extend one of the Nutrient SDK base themes.

Maps to PdfActivityConfiguration$Builder.defaultTheme(int) (resolved by Resources.getIdentifier).

Implementation

final String? defaultThemeResource;