showActionNavigationButtons property

bool? showActionNavigationButtons
final

Show back/forward page-navigation buttons in the toolbar.

When true, arrow buttons for navigating to the previous and next visited page are shown in the viewer toolbar.

Maps to PdfActivityConfiguration$Builder.showActionNavigationButtons(boolean).

Implementation

final bool? showActionNavigationButtons;