showAnnotationListAction property

bool? showAnnotationListAction
final

Show the annotation list action in the viewer toolbar.

When true, a button that opens a list of all annotations in the document is shown in the toolbar.

Maps to PdfActivityConfiguration$Builder.showAnnotationListAction(boolean).

Implementation

final bool? showAnnotationListAction;