showOutlineAction property

bool? showOutlineAction
final

Show the outline (table of contents) action in the viewer toolbar.

When true, a button that opens the document outline / table of contents panel is shown in the toolbar.

Maps to PdfActivityConfiguration$Builder.showOutlineAction(boolean).

Implementation

final bool? showOutlineAction;