showPrintAction property
Show the print action in the viewer toolbar.
When true, a print button is shown in the toolbar overflow menu.
Maps to PdfActivityConfiguration$Builder.showPrintAction(boolean).
Implementation
final bool? showPrintAction;
Show the print action in the viewer toolbar.
When true, a print button is shown in the toolbar overflow menu.
Maps to PdfActivityConfiguration$Builder.showPrintAction(boolean).
final bool? showPrintAction;