showSearchAction property

bool? showSearchAction
final

Show the full-text search action button in the viewer toolbar.

When false, the search icon is removed from the toolbar and the search feature is inaccessible through the UI.

Maps to PdfActivityConfiguration$Builder.showSearchAction(boolean).

Implementation

final bool? showSearchAction;