showThumbnailGridAction property

bool? showThumbnailGridAction
final

Show the thumbnail grid action in the viewer toolbar.

When true, a button that opens a full-screen grid of page thumbnails is shown in the toolbar, allowing the user to jump to any page quickly.

Maps to PdfActivityConfiguration$Builder.showThumbnailGridAction(boolean).

Implementation

final bool? showThumbnailGridAction;