AnnotationAttachment class

Represents an attachment for an annotation

Constructors

AnnotationAttachment({required String id, required String binary, required String contentType})
const
AnnotationAttachment.fromJson(String id, Map<String, dynamic> json)
factory

Properties

binary → String
The Base64 encoded binary data of the attachment
final
contentType → String
The MIME type of the attachment
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited