AnnotationCreatedEvent class final
Emitted when one or more annotations are created.
annotationsJson contains the Instant JSON string for each created annotation, consistent with AnnotationManagerInterface.getAnnotationsJson.
- Inheritance
-
- Object
- NutrientEvent
- AnnotationCreatedEvent
- Mixed-in types
Constructors
-
AnnotationCreatedEvent(List<
String> annotationsJson) -
const
Properties
-
annotations
→ List<
Annotation> -
The typed annotations for this event, parsed from annotationsJson.
no setterinherited
-
annotationsJson
→ List<
String> -
The raw Instant JSON string for each annotation in the event.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
types
→ List<
AnnotationType> -
The AnnotationType of each parsed annotation in this event.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited