fillColorValue property
Color?
get
fillColorValue
Gets the fill color as a Flutter Color object.
Implementation
Color? get fillColorValue => fillColor != null ? Color(fillColor!) : null;
Gets the fill color as a Flutter Color object.
Color? get fillColorValue => fillColor != null ? Color(fillColor!) : null;