AnnotationToolGroup class final

A collapsible group of AnnotationTools in the annotation creation toolbar.

The group occupies one slot on the toolbar showing representative; the other items appear when the slot is expanded (long-press on Android, the group's secondary tools on iOS).

Inheritance

Constructors

AnnotationToolGroup({required AnnotationTool representative, required List<AnnotationTool> items})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
items List<AnnotationTool>
The tools in the group, in display order.
final
representative AnnotationTool
The tool shown when the group is collapsed. Should be one of items.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited