Bookmark class

Copyright © 2018-2026 PSPDFKit GmbH. All rights reserved.

THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE PSPDFKIT LICENSE AGREEMENT. UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES. This notice may not be removed from this file.

A PDF bookmark.

Available extensions

Constructors

Bookmark({String? pdfBookmarkId, String? name, String? actionJson})
const
Bookmark.fromJson(Map<String, dynamic> json)
Creates a Bookmark from a JSON map.
factory

Properties

actionJson String?
JSON-encoded action associated with this bookmark (e.g. GoTo action).
final
hashCode int
The hash code for this object.
no setterinherited
name String?
Display name of the bookmark.
final
pageIndex int?

Available on Bookmark, provided by the BookmarkExtensions extension

Returns the page index this bookmark points to.
no setter
pdfBookmarkId String?
Platform-specific bookmark identifier.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? pdfBookmarkId, String? name, String? actionJson}) Bookmark

Available on Bookmark, provided by the BookmarkExtensions extension

Creates a copy of this bookmark with the specified fields replaced.
isForPage(int pageIndex) bool

Available on Bookmark, provided by the BookmarkExtensions extension

Returns true if this bookmark points to the specified page.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toInstantJson() Map<String, dynamic>

Available on Bookmark, provided by the BookmarkExtensions extension

Converts this bookmark to Instant JSON format.
toJson() Map<String, dynamic>
Converts this bookmark to a JSON map.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited