BookmarkFactory class

Factory methods for creating Bookmark instances.

Since Pigeon-generated classes don't support factory constructors, these are provided as static methods in a separate class.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

forPage({required int pageIndex, String? name, String? pdfBookmarkId}) Bookmark
Creates a bookmark that navigates to a specific page.
fromInstantJson(Map<String, dynamic> json) Bookmark
Creates a bookmark from Instant JSON format.