CaretAnnotation class

Caret annotation

Inheritance
Available extensions

Constructors

CaretAnnotation({String? id, required List<double> bbox, String? createdAt, String? creatorName, String? contents, required Color? color, String? symbol, required int pageIndex, double opacity = 1.0, int? pdfObjectId, List<AnnotationFlag>? flags, String? updatedAt, String? name, String? subject, bool hidden = false, Map<String, dynamic>? customData})
CaretAnnotation.fromJson(Map<String, dynamic> json)
factory

Properties

bbox → List<double>
finalinherited
color → Color?
final
contents → String?
final
createdAt → String?
finalinherited
creatorName → String?
finalinherited
customData → Map<String, dynamic>?
finalinherited
flags → List<AnnotationFlag>?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
hidden → bool
finalinherited
id → String?
finalinherited
name → String?
finalinherited
opacity → double
finalinherited
pageIndex → int
finalinherited
pdfObjectId → int?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subject → String?
finalinherited
symbol → String?
final
type → AnnotationType
finalinherited
updatedAt → String?
finalinherited
v → int
finalinherited

Methods

copyWith({String? id, List<double>? bbox, String? createdAt, int? pageIndex, String? contents, Color? color, String? symbol, String? creatorName, double? opacity, int? pdfObjectId, List<AnnotationFlag>? flags, String? updatedAt, String? name, String? subject, bool? hidden}) → CaretAnnotation

Available on CaretAnnotation, provided by the CaretAnnotationExtensions extension

Creates a copy of this annotation with the given fields replaced with the new values
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited