CircleAnnotation class

Circle annotation

Inheritance
Available extensions

Constructors

CircleAnnotation({String? id, required List<double> bbox, String? createdAt, required int pageIndex, required Color? strokeColor, required double? strokeWidth, Color? fillColor, BorderStyle? borderStyle, List<double>? borderDashArray, double? cloudyBorderIntensity, List<double>? cloudyBorderInset, String? creatorName, double opacity = 1.0, int? pdfObjectId, List<AnnotationFlag>? flags, String? updatedAt, String? name, String? subject, bool hidden = false, String? note, MeasurementScale? measurementScale, MeasurementPrecision? measurementPrecision, List<double>? measurementBBox, Map<String, dynamic>? customData})
CircleAnnotation.fromJson(Map<String, dynamic> json)
factory

Properties

bbox → List<double>
finalinherited
borderDashArray → List<double>?
finalinherited
borderStyle → BorderStyle?
finalinherited
cloudyBorderInset → List<double>?
finalinherited
cloudyBorderIntensity → double?
finalinherited
createdAt → String?
finalinherited
creatorName → String?
finalinherited
customData → Map<String, dynamic>?
finalinherited
fillColor → Color?
finalinherited
flags → List<AnnotationFlag>?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
hidden → bool
finalinherited
id → String?
finalinherited
measurementBBox → List<double>?
finalinherited
measurementPrecision → MeasurementPrecision?
finalinherited
measurementScale → MeasurementScale?
finalinherited
name → String?
finalinherited
note → String?
finalinherited
opacity → double
finalinherited
pageIndex → int
finalinherited
pdfObjectId → int?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strokeColor → Color?
finalinherited
strokeWidth → double?
finalinherited
subject → String?
finalinherited
type → AnnotationType
finalinherited
updatedAt → String?
finalinherited
v → int
finalinherited

Methods

copyWith({String? id, List<double>? bbox, String? createdAt, int? pageIndex, Color? strokeColor, double? strokeWidth, Color? fillColor, BorderStyle? borderStyle, List<double>? borderDashArray, double? cloudyBorderIntensity, List<double>? cloudyBorderInset, String? creatorName, double? opacity, int? pdfObjectId, List<AnnotationFlag>? flags, String? updatedAt, String? name, String? subject, bool? hidden, String? note, MeasurementScale? measurementScale, MeasurementPrecision? measurementPrecision, List<double>? measurementBBox}) → CircleAnnotation

Available on CircleAnnotation, provided by the CircleAnnotationExtensions extension

Creates a copy of this annotation with the given fields replaced with the new values
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited