ComboBoxFormField class

Inheritance

Constructors

ComboBoxFormField({required List<String> defaultValues, required List<int>? selectedIndices, required List<PdfFormOption> options, required List<String>? values})
ComboBoxFormField.fromMap(dynamic map)
factory

Properties

alternativeFieldName → String?
no setterinherited
annotations → List?
no setterinherited
defaultValues → List<String>
final
fullyQualifiedName → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isDirty → bool?
no setterinherited
isNoExport → bool?
no setterinherited
isReadOnly → bool?
no setterinherited
isRequired → bool?
no setterinherited
name → String?
no setterinherited
options → List<PdfFormOption>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedIndices → List<int>?
final
type → PdfFormFieldTypes
no setterinherited
values → List<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
populateCommonFields(dynamic map) → void
inherited
populateWebCommonFields(dynamic map) → void
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited