DocumentErrorEvent class final

Emitted when a document fails to load.

error contains a human-readable description of the failure.

Not applicable on Web (load errors are thrown as exceptions instead).

Inheritance

Constructors

DocumentErrorEvent(String error)
const

Properties

error → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited