EmbeddedFile class

Represents an embedded file that can be attached to a FileAnnotation

Constructors

EmbeddedFile({required String filePath, String? description, String? contentType})
Creates an EmbeddedFile instance
EmbeddedFile.fromJson(Map<String, dynamic> json)
Creates an EmbeddedFile from a JSON map
factory

Properties

contentType → String?
Optional MIME type of the file
final
description → String?
Optional description of the file
final
filePath → String
The path to the file to be embedded
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts the EmbeddedFile to a JSON map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited