FileAnnotation class

File attachment annotation

Inheritance
Available extensions

Constructors

FileAnnotation({String? id, required List<double> bbox, String? createdAt, String? creatorName, FileIconName? iconName, EmbeddedFile? embeddedFile, required int pageIndex, double opacity = 1.0, int? pdfObjectId, List<AnnotationFlag>? flags, String? updatedAt, String? name, String? subject, bool hidden = false, AnnotationAttachment? attachment, Map<String, dynamic>? customData})
Creates a FileAnnotation instance
FileAnnotation.fromJson(Map<String, dynamic> json)
Creates a FileAnnotation from a JSON map
factory

Properties

attachment → AnnotationAttachment?
final
bbox → List<double>
finalinherited
createdAt → String?
finalinherited
creatorName → String?
finalinherited
customData → Map<String, dynamic>?
finalinherited
embeddedFile → EmbeddedFile?
The embedded file associated with this annotation
final
fileAttachmentId → String?
no setter
flags → List<AnnotationFlag>?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
hidden → bool
finalinherited
iconName → FileIconName?
The icon name for the file annotation
final
id → String?
finalinherited
name → String?
finalinherited
opacity → double
finalinherited
pageIndex → int
finalinherited
pdfObjectId → int?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subject → String?
finalinherited
type → AnnotationType
finalinherited
updatedAt → String?
finalinherited
v → int
finalinherited

Methods

copyWith({String? id, List<double>? bbox, String? createdAt, int? pageIndex, FileIconName? iconName, EmbeddedFile? embeddedFile, AnnotationAttachment? attachment, String? creatorName, double? opacity, int? pdfObjectId, List<AnnotationFlag>? flags, String? updatedAt, String? name, String? subject, bool? hidden}) → FileAnnotation

Available on FileAnnotation, provided by the FileAnnotationExtensions extension

Creates a copy of this annotation with the given fields replaced with the new values
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited