setFormFieldValue abstract method

Future<bool> setFormFieldValue(
  1. String value,
  2. String fullyQualifiedName
)

Sets the value of the form field identified by fullyQualifiedName.

Returns true if the field was found and the value was set successfully.

Implementation

Future<bool> setFormFieldValue(String value, String fullyQualifiedName);