FreeTextAnnotation class

Free text annotation

Inheritance
Available extensions

Constructors

FreeTextAnnotation({String? id, required List<double> bbox, String? createdAt, String? creatorName, required TextContent text, required double fontSize, Color? backgroundColor, String font = 'sans-serif', HorizontalTextAlignment? horizontalTextAlign, VerticalAlignment? verticalAlign, Color fontColor = Colors.black, bool? isFitting, bool? disableAutoReturn, Map<String, dynamic>? callout, BorderStyle? borderStyle, List<double>? borderDashArray, double? borderWidth, int rotation = 0, double? cloudyBorderIntensity, List<double>? cloudyBorderInset, required int pageIndex, double opacity = 1.0, int? pdfObjectId, List<AnnotationFlag>? flags, String? updatedAt, String? name, String? subject, bool hidden = false, Map<String, dynamic>? customData})
FreeTextAnnotation.fromJson(Map<String, dynamic> json)
factory

Properties

backgroundColor → Color?
final
bbox → List<double>
finalinherited
borderDashArray → List<double>?
final
borderStyle → BorderStyle?
final
borderWidth → double?
final
callout → Map<String, dynamic>?
final
cloudyBorderInset → List<double>?
final
cloudyBorderIntensity → double?
final
createdAt → String?
finalinherited
creatorName → String?
finalinherited
customData → Map<String, dynamic>?
finalinherited
disableAutoReturn → bool?
final
flags → List<AnnotationFlag>?
finalinherited
font → String
final
fontColor → Color
final
fontSize → double
final
hashCode → int
The hash code for this object.
no setterinherited
hidden → bool
finalinherited
horizontalTextAlign → HorizontalTextAlignment?
final
id → String?
finalinherited
isFitting → bool?
final
name → String?
finalinherited
opacity → double
finalinherited
pageIndex → int
finalinherited
pdfObjectId → int?
finalinherited
rotation → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subject → String?
finalinherited
text → TextContent
final
type → AnnotationType
finalinherited
updatedAt → String?
finalinherited
v → int
finalinherited
verticalAlign → VerticalAlignment?
final

Methods

copyWith({String? id, List<double>? bbox, String? createdAt, int? pageIndex, String? creatorName, TextContent? text, double? fontSize, Color? backgroundColor, String? font, HorizontalTextAlignment? horizontalTextAlign, VerticalAlignment? verticalAlign, Color? fontColor, bool? isFitting, bool? disableAutoReturn, Map<String, dynamic>? callout, BorderStyle? borderStyle, List<double>? borderDashArray, double? borderWidth, int? rotation, double? cloudyBorderIntensity, List<double>? cloudyBorderInset, double? opacity, int? pdfObjectId, List<AnnotationFlag>? flags, String? updatedAt, String? name, String? subject, bool? hidden}) → FreeTextAnnotation

Available on FreeTextAnnotation, provided by the FreeTextAnnotationExtensions extension

Creates a copy of this annotation with the given fields replaced with the new values
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited