GoToAction class

Action to navigate to a specific page and position

Inheritance

Constructors

GoToAction({required int pageIndex, required String destinationType, List<double>? params, Action? subAction})
GoToAction.fromJson(Map<String, dynamic> json)
factory

Properties

destinationType → String
The type of destination (how the page should be displayed)
final
hashCode → int
The hash code for this object.
no setterinherited
pageIndex → int
The page index to navigate to (0-based)
final
params → List<double>?
Optional parameters for the destination type:
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subAction → Action?
Optional sub-action that will be executed after this action
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited