IOSFileConflictResolution enum

Resolution options for file conflicts due to out-of-process file changes or deletion on iOS.

When a PDF file is modified or deleted externally while being viewed in the app, the SDK can handle this conflict in different ways. This enum specifies how to resolve such conflicts.

This option is iOS-only. On Android and Web, this setting is ignored.

Configure via IOSViewConfiguration.fileConflictResolution.

Inheritance
Available extensions

Values

defaultBehavior → const IOSFileConflictResolution

The default conflict resolution behavior. An alert will be shown to the user to choose how to resolve the conflict.

close → const IOSFileConflictResolution

Resolve the conflict by closing the document.

save → const IOSFileConflictResolution

Resolve the conflict by saving the open document and overriding any file changes. If the file was deleted, it will be restored.

reload → const IOSFileConflictResolution

Discard local changes and reload the document from disk.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<IOSFileConflictResolution>
A constant List of the values in this enum, in order of their declaration.