showPageLabels property

bool? showPageLabels
final

Show page labels instead of page numbers.

When true and the document contains named page labels (e.g. "Cover", "i", "ii", "1", "2"), the labels are used in place of numeric page indices throughout the viewer UI.

Maps to PSPDFConfigurationBuilder.showPageLabels.

Implementation

final bool? showPageLabels;