ImageAnnotation class

Image annotation

Inheritance
Mixed-in types
Available extensions

Constructors

ImageAnnotation({String? id, required List<double> bbox, String? createdAt, required int pageIndex, String? creatorName, AnnotationAttachment? attachment, double rotation = 0.0, String? description, String? fileName, String? contentType, String? imageAttachmentId, String? note, bool? isSignature, double opacity = 1.0, int? pdfObjectId, List<AnnotationFlag>? flags, String? updatedAt, String? name, String? subject, bool hidden = false, Map<String, dynamic>? customData})
ImageAnnotation.fromJson(Map<String, dynamic> json, [Map<String, dynamic>? attachments])
factory

Properties

attachment → AnnotationAttachment?
The attachment associated with this annotation
final
bbox → List<double>
finalinherited
contentType → String?
final
createdAt → String?
finalinherited
creatorName → String?
finalinherited
customData → Map<String, dynamic>?
finalinherited
description → String?
final
fileName → String?
final
flags → List<AnnotationFlag>?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
hidden → bool
finalinherited
id → String?
finalinherited
imageAttachmentId → String?
final
isSignature → bool?
final
name → String?
finalinherited
note → String?
final
opacity → double
finalinherited
pageIndex → int
finalinherited
pdfObjectId → int?
finalinherited
rotation → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subject → String?
finalinherited
type → AnnotationType
finalinherited
updatedAt → String?
finalinherited
v → int
finalinherited

Methods

createAttachmentFromJson(String attachmentId, Map<String, dynamic>? attachments) → AnnotationAttachment?
Creates an attachment from JSON data
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited