InkAnnotation class

Represents an ink annotation in PSPDFKit

Inheritance
Available extensions

Constructors

InkAnnotation({String? id, required InkLines lines, required double lineWidth, required List<double> bbox, String? createdAt, required int pageIndex, bool isDrawnNaturally = false, bool? isSignature, Color? strokeColor, Color? backgroundColor, BlendMode? blendMode, String? note, String? creatorName, double opacity = 1.0, int? pdfObjectId, List<AnnotationFlag>? flags, String? updatedAt, String? name, String? subject, bool hidden = false, Map<String, dynamic>? customData})
InkAnnotation.fromJson(Map<String, dynamic> json)
factory

Properties

backgroundColor → Color?
final
bbox → List<double>
finalinherited
blendMode → BlendMode?
final
createdAt → String?
finalinherited
creatorName → String?
finalinherited
customData → Map<String, dynamic>?
finalinherited
flags → List<AnnotationFlag>?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
hidden → bool
finalinherited
id → String?
finalinherited
isDrawnNaturally → bool
final
isSignature → bool?
final
lines → InkLines
final
lineWidth → double
final
name → String?
finalinherited
note → String?
final
opacity → double
finalinherited
pageIndex → int
finalinherited
pdfObjectId → int?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strokeColor → Color?
final
subject → String?
finalinherited
type → AnnotationType
finalinherited
updatedAt → String?
finalinherited
v → int
finalinherited

Methods

copyWith({String? id, List<double>? bbox, String? createdAt, int? pageIndex, Color? strokeColor, double? lineWidth, InkLines? lines, String? creatorName, double? opacity, int? pdfObjectId, List<AnnotationFlag>? flags, String? updatedAt, String? name, String? subject, bool? hidden}) → InkAnnotation

Available on InkAnnotation, provided by the InkAnnotationExtensions extension

Creates a copy of this annotation with the given fields replaced with the new values
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited