InkAnnotationProperties extension

Extension for ink annotation property updates.

on

Methods

withInkLines(List<List<Offset>> lines) AnnotationProperties

Available on AnnotationProperties, provided by the InkAnnotationProperties extension

Creates a modified copy with updated ink lines. Accepts a list of lines where each line is a list of Offset points. Points are converted to x, y, pressure format with default pressure of 1.0.
withRawInkLines(List<List<List<double>>> inkLines) AnnotationProperties

Available on AnnotationProperties, provided by the InkAnnotationProperties extension

Creates a modified copy with updated raw ink lines. Accepts ink lines in the native format: [[x, y, pressure, ...], ...]