InstantAuthFinishedEvent class final

Emitted when Instant JWT re-authentication completes successfully.

Inheritance

Constructors

InstantAuthFinishedEvent(String documentId, String jwt)
const

Properties

documentId String
final
hashCode int
The hash code for this object.
no setterinherited
jwt String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited