LineCaps class

Line caps for line annotations

Constructors

LineCaps({LineCapType? start, LineCapType? end})
const
LineCaps.fromJson(Map<String, dynamic> json)
factory

Properties

end → LineCapType?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → LineCapType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, String>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited