NativeInstanceRegistry class

Registry for native instances.

Platform-specific implementations register their native instances here during view creation.

Constructors

NativeInstanceRegistry()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

get(int viewId, String identifier) Object?
Get a registered native instance.
hasView(int viewId) bool
Whether any native instance is still registered for viewId.
register(int viewId, String identifier, Object instance) → void
Register a native instance for a view.
unregister(int viewId) → void
Unregister all instances for a view.