NoteIcon enum

Note icon types

Inheritance
Available extensions

Values

comment → const NoteIcon

Comment icon

rightPointer → const NoteIcon

Right pointer icon

rightArrow → const NoteIcon

Right arrow icon

check → const NoteIcon

Check icon

circle → const NoteIcon

Circle icon

cross → const NoteIcon

Cross icon

insert → const NoteIcon

Insert icon

newParagraph → const NoteIcon

New paragraph icon

note → const NoteIcon

Note icon

paragraph → const NoteIcon

Paragraph icon

help → const NoteIcon

Help icon

star → const NoteIcon

Star icon

key → const NoteIcon

Key icon

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
instantJsonName → String

Available on NoteIcon, provided by the NoteIconExtension extension

no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<NoteIcon>
A constant List of the values in this enum, in order of their declaration.