isReady property

bool get isReady
override

Whether the controller is ready for use.

Returns true after onReady has been called, indicating that the underlying platform view is created and the controller can interact with the PDF viewer.

Implementation

bool get isReady => _ready;