close abstract method

Future<bool> close()

Closes the document and releases all associated resources.

Must be called when done with a headless document opened via adapter.openDocument(). View-attached documents are closed automatically when the view is disposed.

Implementation

Future<bool> close();