onViewCreated property
Called when the platform view has been created and is ready to use.
Implementation
final void Function(NutrientViewHandle handle)? onViewCreated;
Called when the platform view has been created and is ready to use.
final void Function(NutrientViewHandle handle)? onViewCreated;