copyWith method

NutrientViewConfiguration copyWith({
  1. ScrollDirection? scrollDirection,
  2. PageLayoutMode? pageLayoutMode,
  3. PageTransition? pageTransition,
  4. bool? firstPageAlwaysSingle,
  5. UserInterfaceViewMode? userInterfaceViewMode,
  6. ThumbnailBarMode? thumbnailBarMode,
  7. AppearanceMode? appearanceMode,
  8. int? startPage,
  9. bool? enableTextSelection,
  10. bool? enableAnnotationEditing,
  11. bool? enableFormEditing,
  12. bool? disableAutosave,
  13. bool? enableInstantComments,
  14. double? minimumZoomScale,
  15. double? maximumZoomScale,
  16. SignatureSavingStrategy? signatureSavingStrategy,
  17. SignatureCreationConfiguration? signatureCreationConfiguration,
  18. AndroidViewConfiguration? androidConfig,
  19. IOSViewConfiguration? iosConfig,
  20. Object? webConfig,
  21. Map<String, String>? aiAssistantConfiguration,
  22. String? password,
})

Returns a copy of this configuration with the given fields replaced.

Passing null for a parameter keeps the current value — fields cannot be cleared through copyWith.

Implementation

NutrientViewConfiguration copyWith({
  ScrollDirection? scrollDirection,
  PageLayoutMode? pageLayoutMode,
  PageTransition? pageTransition,
  bool? firstPageAlwaysSingle,
  UserInterfaceViewMode? userInterfaceViewMode,
  ThumbnailBarMode? thumbnailBarMode,
  AppearanceMode? appearanceMode,
  int? startPage,
  bool? enableTextSelection,
  bool? enableAnnotationEditing,
  bool? enableFormEditing,
  bool? disableAutosave,
  bool? enableInstantComments,
  double? minimumZoomScale,
  double? maximumZoomScale,
  SignatureSavingStrategy? signatureSavingStrategy,
  SignatureCreationConfiguration? signatureCreationConfiguration,
  AndroidViewConfiguration? androidConfig,
  IOSViewConfiguration? iosConfig,
  Object? webConfig,
  Map<String, String>? aiAssistantConfiguration,
  String? password,
}) {
  return NutrientViewConfiguration(
    scrollDirection: scrollDirection ?? this.scrollDirection,
    pageLayoutMode: pageLayoutMode ?? this.pageLayoutMode,
    pageTransition: pageTransition ?? this.pageTransition,
    firstPageAlwaysSingle:
        firstPageAlwaysSingle ?? this.firstPageAlwaysSingle,
    userInterfaceViewMode:
        userInterfaceViewMode ?? this.userInterfaceViewMode,
    thumbnailBarMode: thumbnailBarMode ?? this.thumbnailBarMode,
    appearanceMode: appearanceMode ?? this.appearanceMode,
    startPage: startPage ?? this.startPage,
    enableTextSelection: enableTextSelection ?? this.enableTextSelection,
    enableAnnotationEditing:
        enableAnnotationEditing ?? this.enableAnnotationEditing,
    enableFormEditing: enableFormEditing ?? this.enableFormEditing,
    disableAutosave: disableAutosave ?? this.disableAutosave,
    enableInstantComments:
        enableInstantComments ?? this.enableInstantComments,
    minimumZoomScale: minimumZoomScale ?? this.minimumZoomScale,
    maximumZoomScale: maximumZoomScale ?? this.maximumZoomScale,
    signatureSavingStrategy:
        signatureSavingStrategy ?? this.signatureSavingStrategy,
    signatureCreationConfiguration:
        signatureCreationConfiguration ?? this.signatureCreationConfiguration,
    androidConfig: androidConfig ?? this.androidConfig,
    iosConfig: iosConfig ?? this.iosConfig,
    webConfig: webConfig ?? this.webConfig,
    aiAssistantConfiguration:
        aiAssistantConfiguration ?? this.aiAssistantConfiguration,
    password: password ?? this.password,
  );
}