NutrientWebToolbarItemType enum

Copyright © 2024-2026 PSPDFKit GmbH. All rights reserved.

THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE PSPDFKIT LICENSE AGREEMENT. UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES. This notice may not be removed from this file.

Inheritance
Available extensions

Values

sidebarThumbnails → const NutrientWebToolbarItemType
sidebarDocumentOutline → const NutrientWebToolbarItemType
sidebarAnnotations → const NutrientWebToolbarItemType
sidebarBookmarks → const NutrientWebToolbarItemType
sidebarSignatures → const NutrientWebToolbarItemType
sidebarLayers → const NutrientWebToolbarItemType
sidebarAttachments → const NutrientWebToolbarItemType
pager → const NutrientWebToolbarItemType
pan → const NutrientWebToolbarItemType
zoomOut → const NutrientWebToolbarItemType
zoomIn → const NutrientWebToolbarItemType
zoomMode → const NutrientWebToolbarItemType
spacer → const NutrientWebToolbarItemType
annotate → const NutrientWebToolbarItemType
ink → const NutrientWebToolbarItemType
highlighter → const NutrientWebToolbarItemType
textHighlighter → const NutrientWebToolbarItemType
inkEraser → const NutrientWebToolbarItemType
signature → const NutrientWebToolbarItemType
image → const NutrientWebToolbarItemType
stamp → const NutrientWebToolbarItemType
note → const NutrientWebToolbarItemType
text → const NutrientWebToolbarItemType
line → const NutrientWebToolbarItemType
arrow → const NutrientWebToolbarItemType
rectangle → const NutrientWebToolbarItemType
cloudyRectangle → const NutrientWebToolbarItemType
dashedRectangle → const NutrientWebToolbarItemType
ellipse → const NutrientWebToolbarItemType
cloudyEllipse → const NutrientWebToolbarItemType
dashedEllipse → const NutrientWebToolbarItemType
polygon → const NutrientWebToolbarItemType
cloudyPolygon → const NutrientWebToolbarItemType
dashedPolygon → const NutrientWebToolbarItemType
polyline → const NutrientWebToolbarItemType
print → const NutrientWebToolbarItemType
documentEditor → const NutrientWebToolbarItemType
documentCrop → const NutrientWebToolbarItemType
exportPdf → const NutrientWebToolbarItemType
debug → const NutrientWebToolbarItemType
contentEditor → const NutrientWebToolbarItemType
multiAnnotationsSelection → const NutrientWebToolbarItemType
callout → const NutrientWebToolbarItemType
responsiveGroup → const NutrientWebToolbarItemType
custom → const NutrientWebToolbarItemType
measurements → const NutrientWebToolbarItemType
linearizedDownloadIndicator → const NutrientWebToolbarItemType
comment → const NutrientWebToolbarItemType
aiAssistant → const NutrientWebToolbarItemType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
name String

Available on NutrientWebToolbarItemType, provided by the WebToolbarItemTypeX extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NutrientWebToolbarItemType>
A constant List of the values in this enum, in order of their declaration.