spreadsheetMaximumContentHeightPerSheet property
Maximum height (in millimeters) for spreadsheet content per sheet.
This setting controls the maximum height of content that will be rendered for each sheet in Excel spreadsheets. Content exceeding this height will be truncated. The default value is platform-specific.
Implementation
final num? spreadsheetMaximumContentHeightPerSheet;