PageChangedEvent class final
Emitted when the viewer navigates to a different page.
pageIndex is zero-based.
- Inheritance
-
- Object
- NutrientEvent
- PageChangedEvent
Constructors
- PageChangedEvent(int pageIndex)
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited