PageTransitionWebName extension
Extension that provides the Web SDK string name for PageTransition values.
Used internally by the configuration builder when serialising NutrientViewConfiguration for the Nutrient Web SDK.
Only PageTransition.scrollContinuous and PageTransition.disabled have
dedicated Web SDK equivalents. All other values default to 'PER_SPREAD'.
Properties
- webName → String?
-
Available on PageTransition, provided by the PageTransitionWebName extension
Returns the Web SDKlayoutModestring for this transition, ornullwhen the transition is not expressible in the Web SDK.no setter