webName property

String? get webName

Returns the Web SDK layoutMode string for this transition, or null when the transition is not expressible in the Web SDK.

Implementation

String? get webName {
  switch (this) {
    case PageTransition.scrollContinuous:
      return 'CONTINUOUS';
    case PageTransition.disabled:
      return 'DISABLED';
    case PageTransition.scrollPerSpread:
    default:
      return 'PER_SPREAD';
  }
}