PdfVersion enum

The PDF version to target when saving a document.

Inheritance
Available extensions

Values

pdf_1_0 → const PdfVersion
pdf_1_1 → const PdfVersion
pdf_1_2 → const PdfVersion
pdf_1_3 → const PdfVersion
pdf_1_4 → const PdfVersion
pdf_1_5 → const PdfVersion
pdf_1_6 → const PdfVersion
pdf_1_7 → const PdfVersion

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PdfVersion>
A constant List of the values in this enum, in order of their declaration.