SignatureColorPreset class

A color preset offered in the signature creation UI.

id, defaultMessage and description localize the preset's accessibility label where the platform supports it.

Constructors

SignatureColorPreset({required Color color, String? id, String? defaultMessage, String? description})

Properties

color → Color
final
defaultMessage → String?
final
description → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited