SignatureCreationConfiguration class

Configuration for the signature creation UI.

Option Android iOS Web
creationModes ✅ ✅ ✅
colorOptions ✅ ✅ ✅
fonts ❌ (no native API) ✅ ✅
androidSignatureOrientation ✅ — —
iosSignatureAspectRatio — ✅ —

Constructors

SignatureCreationConfiguration({List<SignatureCreationMode>? creationModes, SignatureColorOptions? colorOptions, AspectRatio? iosSignatureAspectRatio, NutrientAndroidSignatureOrientation? androidSignatureOrientation, List<String>? fonts})

Properties

androidSignatureOrientation → NutrientAndroidSignatureOrientation?
Orientation of the signature dialog (Android only).
final
colorOptions → SignatureColorOptions?
The three ink/text color presets offered by the signature UI.
final
creationModes → List<SignatureCreationMode>?
The creation modes (tabs) offered by the signature UI, in order.
final
fonts → List<String>?
Fonts offered for typed signatures (iOS and Web).
final
hashCode → int
The hash code for this object.
no setterinherited
iosSignatureAspectRatio → AspectRatio?
Aspect ratio of the signing area (iOS only).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited