SoundAnnotation class

Sound annotation

Inheritance
Available extensions

Constructors

SoundAnnotation({String? id, required List<double> bbox, String? createdAt, String? creatorName, required String soundUrl, String? icon, required int pageIndex, double opacity = 1.0, int? pdfObjectId, List<AnnotationFlag>? flags, String? updatedAt, String? name, String? subject, bool hidden = false, Map<String, dynamic>? customData})
SoundAnnotation.fromJson(Map<String, dynamic> json)
factory

Properties

bbox → List<double>
finalinherited
createdAt → String?
finalinherited
creatorName → String?
finalinherited
customData → Map<String, dynamic>?
finalinherited
flags → List<AnnotationFlag>?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
hidden → bool
finalinherited
icon → String?
final
id → String?
finalinherited
name → String?
finalinherited
opacity → double
finalinherited
pageIndex → int
finalinherited
pdfObjectId → int?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
soundUrl → String
final
subject → String?
finalinherited
type → AnnotationType
finalinherited
updatedAt → String?
finalinherited
v → int
finalinherited

Methods

copyWith({String? id, List<double>? bbox, String? createdAt, int? pageIndex, String? soundUrl, String? icon, String? creatorName, double? opacity, int? pdfObjectId, List<AnnotationFlag>? flags, String? updatedAt, String? name, String? subject, bool? hidden}) → SoundAnnotation

Available on SoundAnnotation, provided by the SoundAnnotationExtensions extension

Creates a copy of this annotation with the given fields replaced with the new values
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited