StampType enum

Inheritance
Available extensions

Values

approved → const StampType
notApproved → const StampType
draft → const StampType
final_ → const StampType
completed → const StampType
confidential → const StampType
forPublicRelease → const StampType
notForPublicRelease → const StampType
forComment → const StampType
void_ → const StampType
preliminaryResults → const StampType
informationOnly → const StampType
rejected → const StampType
accepted → const StampType
initialHere → const StampType
signHere → const StampType
witness → const StampType
asIs → const StampType
departmental → const StampType
experimental → const StampType
expired → const StampType
sold → const StampType
topSecret → const StampType
revised → const StampType
rejectedWithText → const StampType
custom → const StampType

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
name → String

Available on StampType, provided by the StampTypeExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<StampType>
A constant List of the values in this enum, in order of their declaration.