TextMarkupAnnotation class abstract

Base class for text markup annotations (highlight, underline, strikeout, squiggly)

Inheritance
Available extensions

Constructors

TextMarkupAnnotation({String? id, required AnnotationType type, required List<double> bbox, String? createdAt, String? creatorName, required List<List<double>> rects, BlendMode? blendMode, required Color? color, String? note, required int pageIndex, double opacity = 1.0, int? pdfObjectId, List<AnnotationFlag>? flags, String? updatedAt, String? name, String? subject, bool hidden = false, Map<String, dynamic>? customData})

Properties

bbox → List<double>
finalinherited
blendMode → BlendMode?
final
color → Color?
final
createdAt → String?
finalinherited
creatorName → String?
finalinherited
customData → Map<String, dynamic>?
finalinherited
flags → List<AnnotationFlag>?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
hidden → bool
finalinherited
id → String?
finalinherited
name → String?
finalinherited
note → String?
final
opacity → double
finalinherited
pageIndex → int
finalinherited
pdfObjectId → int?
finalinherited
rects → List<List<double>>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subject → String?
finalinherited
type → AnnotationType
finalinherited
updatedAt → String?
finalinherited
v → int
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited