Type3DAnnotation class

3D annotation

Inheritance
Available extensions

Constructors

Type3DAnnotation({String? id, required List<double> bbox, String? createdAt, String? creatorName, required String source, String? poster, Map<String, dynamic>? viewSettings, required int pageIndex, double opacity = 1.0, int? pdfObjectId, List<AnnotationFlag>? flags, String? updatedAt, String? name, String? subject, bool hidden = false, Map<String, dynamic>? customData})
Type3DAnnotation.fromJson(Map<String, dynamic> json)
factory

Properties

bbox → List<double>
finalinherited
createdAt → String?
finalinherited
creatorName → String?
finalinherited
customData → Map<String, dynamic>?
finalinherited
flags → List<AnnotationFlag>?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
hidden → bool
finalinherited
id → String?
finalinherited
name → String?
finalinherited
opacity → double
finalinherited
pageIndex → int
finalinherited
pdfObjectId → int?
finalinherited
poster → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → String
final
subject → String?
finalinherited
type → AnnotationType
finalinherited
updatedAt → String?
finalinherited
v → int
finalinherited
viewSettings → Map<String, dynamic>?
final

Methods

copyWith({String? id, List<double>? bbox, String? createdAt, int? pageIndex, String? source, String? poster, Map<String, dynamic>? viewSettings, String? creatorName, double? opacity, int? pdfObjectId, List<AnnotationFlag>? flags, String? updatedAt, String? name, String? subject, bool? hidden}) → Type3DAnnotation

Available on Type3DAnnotation, provided by the Type3DAnnotationExtensions extension

Creates a copy of this annotation with the given fields replaced with the new values
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited