UriAction class

Action to open a URL in a web browser

Inheritance

Constructors

UriAction({required String uri, Action? subAction})
UriAction.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subAction Action?
Optional sub-action that will be executed after this action
finalinherited
uri String
The URL to open
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited