UserInterfaceViewMode enum

Controls when the viewer toolbar and overlays are shown.

Platform availability:

  • Android: maps to PdfActivityConfiguration$Builder.userInterfaceViewMode.
  • iOS: maps to PSPDFConfigurationBuilder.userInterfaceViewMode.
  • Web: only always and never have a direct equivalent (initialViewState.showToolbar). Prefer WebViewConfiguration.showToolbar for finer-grained web control.
Inheritance
Available extensions

Values

automatic → const UserInterfaceViewMode

Show or hide the UI automatically based on user interaction.

The toolbar and overlays appear when the user taps the document and hide after a short idle period.

always → const UserInterfaceViewMode

Always keep the toolbar and overlays visible.

automaticNoFirstLastPage → const UserInterfaceViewMode

Automatic visibility, but the UI remains visible on the first and last page.

never → const UserInterfaceViewMode

Never show the UI (full immersive / kiosk mode).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<UserInterfaceViewMode>
A constant List of the values in this enum, in order of their declaration.