WatermarkAnnotation class

Watermark annotation

Inheritance
Available extensions

Constructors

WatermarkAnnotation({String? id, required List<double> bbox, String? createdAt, String? creatorName, required String text, required double rotation, String? fontFamily, double? fontSize, Color? color, required int pageIndex, int? pdfObjectId, List<AnnotationFlag>? flags, String? updatedAt, double opacity = 1.0, String? name, String? subject, bool hidden = false, Map<String, dynamic>? customData})
WatermarkAnnotation.fromJson(Map<String, dynamic> json)
factory

Properties

bbox → List<double>
finalinherited
color → Color?
final
createdAt → String?
finalinherited
creatorName → String?
finalinherited
customData → Map<String, dynamic>?
finalinherited
flags → List<AnnotationFlag>?
finalinherited
fontFamily → String?
final
fontSize → double?
final
hashCode → int
The hash code for this object.
no setterinherited
hidden → bool
finalinherited
id → String?
finalinherited
name → String?
finalinherited
opacity → double
finalinherited
pageIndex → int
finalinherited
pdfObjectId → int?
finalinherited
rotation → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subject → String?
finalinherited
text → String
final
type → AnnotationType
finalinherited
updatedAt → String?
finalinherited
v → int
finalinherited

Methods

copyWith({String? id, List<double>? bbox, String? createdAt, int? pageIndex, String? text, double? rotation, String? fontFamily, double? fontSize, Color? color, String? creatorName, double? opacity, int? pdfObjectId, List<AnnotationFlag>? flags, String? updatedAt, String? name, String? subject, bool? hidden}) → WatermarkAnnotation

Available on WatermarkAnnotation, provided by the WatermarkAnnotationExtensions extension

Creates a copy of this annotation with the given fields replaced with the new values
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited