annotationToolbarItems property
Callback that returns the annotation toolbar items for a given annotation type.
Implementation
final NutrientWebAnnotationToolbarItemsCallback? annotationToolbarItems;
Callback that returns the annotation toolbar items for a given annotation type.
final NutrientWebAnnotationToolbarItemsCallback? annotationToolbarItems;