autoCloseThreshold property
Seconds of inactivity before the document is automatically closed.
Corresponds to autoCloseThreshold.
Implementation
final num? autoCloseThreshold;
Seconds of inactivity before the document is automatically closed.
Corresponds to autoCloseThreshold.
final num? autoCloseThreshold;