canScrollWhileDrawing property
Whether the user can scroll the document while drawing an annotation.
Corresponds to initialViewState.canScrollWhileDrawing.
Implementation
final bool? canScrollWhileDrawing;
Whether the user can scroll the document while drawing an annotation.
Corresponds to initialViewState.canScrollWhileDrawing.
final bool? canScrollWhileDrawing;