keepSelectedTool property
Keep the currently selected annotation tool active after use.
Corresponds to initialViewState.keepSelectedTool.
Implementation
final bool? keepSelectedTool;
Keep the currently selected annotation tool active after use.
Corresponds to initialViewState.keepSelectedTool.
final bool? keepSelectedTool;