preventTextCopy property
Prevent the user from copying text from the document. Corresponds to preventTextCopy.
Implementation
final bool? preventTextCopy;
Prevent the user from copying text from the document. Corresponds to preventTextCopy.
final bool? preventTextCopy;