previewRedactionMode property
Show a preview of the redaction overlay before applying.
Corresponds to initialViewState.previewRedactionMode.
Implementation
final bool? previewRedactionMode;
Show a preview of the redaction overlay before applying.
Corresponds to initialViewState.previewRedactionMode.
final bool? previewRedactionMode;