WidgetAnnotation class

Widget annotation (form fields)

Inheritance
Available extensions

Constructors

WidgetAnnotation({String? id, required List<double> bbox, String? createdAt, String? creatorName, required String fieldType, String? fieldName, dynamic value, List<String>? options, bool? readOnly, bool? required, bool? multiline, required int pageIndex, double opacity = 1.0, int? pdfObjectId, List<AnnotationFlag>? flags, String? updatedAt, String? name, String? subject, bool hidden = false, Map<String, dynamic>? customData})
WidgetAnnotation.fromJson(Map<String, dynamic> json)
factory

Properties

bbox → List<double>
finalinherited
createdAt → String?
finalinherited
creatorName → String?
finalinherited
customData → Map<String, dynamic>?
finalinherited
fieldName → String?
final
fieldType → String
final
flags → List<AnnotationFlag>?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
hidden → bool
finalinherited
id → String?
finalinherited
multiline → bool?
final
name → String?
finalinherited
opacity → double
finalinherited
options → List<String>?
final
pageIndex → int
finalinherited
pdfObjectId → int?
finalinherited
readOnly → bool?
final
required → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subject → String?
finalinherited
type → AnnotationType
finalinherited
updatedAt → String?
finalinherited
v → int
finalinherited
value → dynamic
final

Methods

copyWith({String? id, List<double>? bbox, String? createdAt, int? pageIndex, String? fieldName, String? fieldType, dynamic value, List<String>? options, bool? readOnly, bool? required, bool? multiline, String? creatorName, double? opacity, int? pdfObjectId, List<AnnotationFlag>? flags, String? updatedAt, String? name, String? subject, bool? hidden}) → WidgetAnnotation

Available on WidgetAnnotation, provided by the WidgetAnnotationExtensions extension

Creates a copy of this annotation with the given fields replaced with the new values
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited