kImageDocumentExtensions top-level constant

Set<String> const kImageDocumentExtensions

Copyright © 2018-2026 PSPDFKit GmbH. All rights reserved.

THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE PSPDFKIT LICENSE AGREEMENT. UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES. This notice may not be removed from this file.

File extensions Nutrient treats as image documents — a single annotatable image page rather than a PDF. Mirrors the image formats supported by the native image-document loaders on Android, iOS, and Web.

Implementation

/// File extensions Nutrient treats as image documents — a single annotatable
/// image page rather than a PDF. Mirrors the image formats supported by the
/// native image-document loaders on Android, iOS, and Web.
const Set<String> kImageDocumentExtensions = {
  'jpg',
  'jpeg',
  'png',
  'tif',
  'tiff',
  'gif',
  'bmp',
  'webp',
};