showPageLabels property
Show page labels instead of page numbers in the thumbnail bar and navigation.
When true and the document contains named page labels (e.g. "Cover",
"i", "ii", "1", "2"), the labels are used in place of numeric page indices.
Maps to PdfActivityConfiguration$Builder.showPageLabels(boolean).
Implementation
final bool? showPageLabels;