AnnotationMenuConfiguration class

Configuration for annotation contextual menu customization.

Constructors

AnnotationMenuConfiguration({List<AnnotationMenuAction> itemsToRemove = const <AnnotationMenuAction>[], List<AnnotationMenuAction> itemsToDisable = const <AnnotationMenuAction>[], bool showStylePicker = true, bool groupMarkupItems = true, int? maxVisibleItems})
const

Properties

groupMarkupItems bool
Whether to group markup annotations (highlight, underline, etc.) together.
final
hashCode int
The hash code for this object.
no setterinherited
itemsToDisable List<AnnotationMenuAction>
Default menu actions to disable (show as grayed out).
final
itemsToRemove List<AnnotationMenuAction>
Default menu actions to remove from the contextual menu.
final
maxVisibleItems int?
Maximum number of items to show before creating an overflow menu.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showStylePicker bool
Whether to show the default style picker. Defaults to true.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toPigeonData() AnnotationMenuConfigurationData
Converts to Pigeon data object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited