groupMarkupItems property

bool groupMarkupItems
getter/setter pair

Whether to group markup annotation actions together in the menu.

When true, related markup actions (highlight, underline, etc.) are visually grouped in the menu for better organization.

Platform Support: iOS only (ignored on Android and Web)

Implementation

bool groupMarkupItems;