itemsToRemove property
List of default annotation menu actions to remove completely from the menu.
These actions will not appear in the contextual menu at all. Use this when you want to completely hide certain functionality.
Example: Remove delete action for read-only annotations
itemsToRemove: [AnnotationMenuAction.delete]
Implementation
List<AnnotationMenuAction> itemsToRemove;