color property
Color?
get
color
Gets the stroke color as a Flutter Color object.
Implementation
Color? get color => strokeColor != null ? Color(strokeColor!) : null;
Gets the stroke color as a Flutter Color object.
Color? get color => strokeColor != null ? Color(strokeColor!) : null;