showActionNavigationButtons property

bool? showActionNavigationButtons
final

Show back/forward page-navigation buttons in the navigation bar.

When true, arrow buttons for navigating to the previous and next visited page are added to the viewer's navigation bar.

Maps to PSPDFConfigurationBuilder.showActionNavigationButtonsAsThumbnails and related navigation button configuration.

Implementation

final bool? showActionNavigationButtons;