LineAnnotation class

Line annotation for drawing straight lines on a page

Inheritance
Available extensions

Constructors

LineAnnotation({String? id, required List<double> bbox, String? createdAt, required int pageIndex, required Color? strokeColor, required double? strokeWidth, required List<double> startPoint, required List<double> endPoint, LineCaps? lineCaps, Color? fillColor, BorderStyle? borderStyle, List<double>? borderDashArray, double? cloudyBorderIntensity, List<double>? cloudyBorderInset, String? creatorName, double opacity = 1.0, int? pdfObjectId, List<AnnotationFlag>? flags, String? updatedAt, String? name, String? subject, bool hidden = false, String? note, MeasurementScale? measurementScale, MeasurementPrecision? measurementPrecision, List<double>? measurementBBox, Map<String, dynamic>? customData})
LineAnnotation.fromJson(Map<String, dynamic> json)
factory

Properties

bbox List<double>
finalinherited
borderDashArray List<double>?
finalinherited
borderStyle BorderStyle?
finalinherited
cloudyBorderInset List<double>?
finalinherited
cloudyBorderIntensity double?
finalinherited
createdAt String?
finalinherited
creatorName String?
finalinherited
customData Map<String, dynamic>?
finalinherited
endPoint List<double>
final
fillColor Color?
finalinherited
flags List<AnnotationFlag>?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
hidden bool
finalinherited
id String?
finalinherited
lineCaps LineCaps?
final
measurementBBox List<double>?
finalinherited
measurementPrecision MeasurementPrecision?
finalinherited
measurementScale MeasurementScale?
finalinherited
name String?
finalinherited
note String?
finalinherited
opacity double
finalinherited
pageIndex int
finalinherited
pdfObjectId int?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startPoint List<double>
final
strokeColor Color?
finalinherited
strokeWidth double?
finalinherited
subject String?
finalinherited
type AnnotationType
finalinherited
updatedAt String?
finalinherited
v int
finalinherited

Methods

copyWith({String? id, List<double>? bbox, String? createdAt, int? pageIndex, List<double>? startPoint, List<double>? endPoint, Color? strokeColor, double? strokeWidth, LineCaps? lineCaps, BorderStyle? borderStyle, List<double>? borderDashArray, String? creatorName, double? opacity, int? pdfObjectId, List<AnnotationFlag>? flags, String? updatedAt, String? name, String? subject, bool? hidden}) LineAnnotation

Available on LineAnnotation, provided by the LineAnnotationExtensions extension

Creates a copy of this annotation with the given fields replaced with the new values
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited