NutrientAnnotationToolbarItemsCallbackOptions class

Copyright © 2024-2026 PSPDFKit GmbH. All rights reserved.

THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE PSPDFKIT LICENSE AGREEMENT. UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES. This notice may not be removed from this file.

Constructors

NutrientAnnotationToolbarItemsCallbackOptions({required List<NutrientWebAnnotationToolbarItem> defaultAnnotationToolbarItems, required bool? hasDesktopLayout})

Properties

defaultAnnotationToolbarItems List<NutrientWebAnnotationToolbarItem>
final
hasDesktopLayout bool?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited