setAnnotationMenuConfiguration abstract method

Future<bool?> setAnnotationMenuConfiguration(
  1. AnnotationMenuConfiguration configuration
)

Sets the annotation menu configuration dynamically. This allows you to update the annotation contextual menu configuration at runtime. @param configuration The annotation menu configuration to apply. @return True if the configuration was set successfully, false otherwise.

Implementation

Future<bool?> setAnnotationMenuConfiguration(
  AnnotationMenuConfiguration configuration,
);