NutrientWebAnnotationToolbarItemType enum

Copyright © 2024-2026 PSPDFKit GmbH. All rights reserved.

THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE PSPDFKIT LICENSE AGREEMENT. UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES. This notice may not be removed from this file.

Inheritance
  • Object
  • Enum
  • NutrientWebAnnotationToolbarItemType
Available extensions

Values

spacer → const NutrientWebAnnotationToolbarItemType
back → const NutrientWebAnnotationToolbarItemType
close → const NutrientWebAnnotationToolbarItemType
delete → const NutrientWebAnnotationToolbarItemType
custom → const NutrientWebAnnotationToolbarItemType
strokeColor → const NutrientWebAnnotationToolbarItemType
fillColor → const NutrientWebAnnotationToolbarItemType
backgroundColor → const NutrientWebAnnotationToolbarItemType
color → const NutrientWebAnnotationToolbarItemType
outlineColor → const NutrientWebAnnotationToolbarItemType
textColor → const NutrientWebAnnotationToolbarItemType
opacity → const NutrientWebAnnotationToolbarItemType
lineWidth → const NutrientWebAnnotationToolbarItemType
borderWidth → const NutrientWebAnnotationToolbarItemType
borderColor → const NutrientWebAnnotationToolbarItemType
borderStyle → const NutrientWebAnnotationToolbarItemType
lineStyle → const NutrientWebAnnotationToolbarItemType
linecapsDasharray → const NutrientWebAnnotationToolbarItemType
blendMode → const NutrientWebAnnotationToolbarItemType
font → const NutrientWebAnnotationToolbarItemType
annotationNote → const NutrientWebAnnotationToolbarItemType
annotationComment → const NutrientWebAnnotationToolbarItemType
noteIcon → const NutrientWebAnnotationToolbarItemType
overlayText → const NutrientWebAnnotationToolbarItemType
applyRedactions → const NutrientWebAnnotationToolbarItemType
overlay → const NutrientWebAnnotationToolbarItemType
measurementType → const NutrientWebAnnotationToolbarItemType
measurementScale → const NutrientWebAnnotationToolbarItemType
snapping → const NutrientWebAnnotationToolbarItemType
cropCurrent → const NutrientWebAnnotationToolbarItemType
cropAll → const NutrientWebAnnotationToolbarItemType
addTextBox → const NutrientWebAnnotationToolbarItemType
cancelSave → const NutrientWebAnnotationToolbarItemType
counterclockwiseRotation → const NutrientWebAnnotationToolbarItemType
clockwiseRotation → const NutrientWebAnnotationToolbarItemType
formButton → const NutrientWebAnnotationToolbarItemType
formText → const NutrientWebAnnotationToolbarItemType
formRadio → const NutrientWebAnnotationToolbarItemType
formCheckbox → const NutrientWebAnnotationToolbarItemType
formCombobox → const NutrientWebAnnotationToolbarItemType
formListbox → const NutrientWebAnnotationToolbarItemType
formSignature → const NutrientWebAnnotationToolbarItemType
formDate → const NutrientWebAnnotationToolbarItemType
separatorEndEnforce → const NutrientWebAnnotationToolbarItemType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
name String

Available on NutrientWebAnnotationToolbarItemType, provided by the WebAnnotationToolbarTypeX extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NutrientWebAnnotationToolbarItemType>
A constant List of the values in this enum, in order of their declaration.