PdfConfiguration class
A class representing the configuration options for a PDF document.
Constructors
-
PdfConfiguration({ScrollDirection? scrollDirection, PageTransition? pageTransition, bool? enableTextSelection, bool? disableAutosave, PageLayoutMode? pageLayoutMode, SpreadFitting? spreadFitting, bool? showPageLabels, int? startPage, bool? documentLabelEnabled, bool? firstPageAlwaysSingle, bool? invertColors, String? password, bool? androidGrayScale, bool? inlineSearch, String? toolbarTitle, UserInterfaceViewMode? userInterfaceViewMode, bool? immersiveMode, AppearanceMode? appearanceMode, List<
String> ? settingsMenuItems, bool? androidShowSearchAction, bool? androidShowOutlineAction, bool? androidShowBookmarksAction, bool? androidEnableDocumentEditor, bool? androidContentEditorEnabled, bool? androidShowPrintAction, bool? androidShowDocumentInfoView, bool? androidShowAnnotationListAction, bool? androidShowAnnotationCreationAction, String? androidDarkThemeResource, String? androidDefaultThemeResource, List<String> ? iOSLeftBarButtonItems, List<String> ? iOSRightBarButtonItems, bool? iOSAllowToolbarTitleChange, IOSBookmarkIndicatorMode? iOSBookmarkIndicatorMode, bool? iOSBookmarkIndicatorInteractionEnabled, IOSFileConflictResolution? iOSFileConflictResolution, ThumbnailBarMode? showThumbnailBar, bool? androidShowThumbnailGridAction, bool? enableAnnotationEditing, bool? enableFormEditing, bool? enableInstantComments, PdfWebConfiguration? webConfiguration, List<String> ? editableAnnotationTypes, List<ToolbarMenuItems> ? toolbarMenuItems, bool? enableMeasurementTools, bool? measurementSnappingEnabled, bool? enableMagnifier, List<MeasurementValueConfiguration> ? measurementValueConfigurations, List? annotationToolsGrouping, double? defaultZoomScale, double? maximumZoomScale, double? minimumZoomScale, SignatureSavingStrategy? signatureSavingStrategy, SignatureCreationConfiguration? signatureCreationConfiguration, AIAssistantConfiguration? aiAssistantConfiguration, bool? androidEnableAiAssistant, AnnotationMenuConfiguration? annotationMenuConfiguration, ThemeConfiguration? themeConfiguration})
Properties
- aiAssistantConfiguration → AIAssistantConfiguration?
-
final
- androidContentEditorEnabled → bool?
-
Sets whether to enable the content editor. Defaults to true.
This feature requires a content editor license.
final
- androidDarkThemeResource → String?
-
Sets the dark theme XML resource for the Android toolbar.
final
- androidDefaultThemeResource → String?
-
Sets the default theme XML resource for the Android toolbar.
final
- androidEnableAiAssistant → bool?
-
final
- androidEnableDocumentEditor → bool?
-
Sets whether to enable the document editor. Defaults to true.
This feature requires a document editor license.
final
- androidGrayScale → bool?
-
Sets whether to show the document in gray scale. Defaults to false.
final
- androidShowAnnotationCreationAction → bool?
-
Sets whether to show the annotation creation action in the Android toolbar.
Defaults to true. When set to false, hides the main annotation button while
keeping annotation editing functionality enabled.
final
- androidShowAnnotationListAction → bool?
-
Sets whether to show the annotation list action in the Android toolbar.
Defaults to true.
final
- androidShowBookmarksAction → bool?
-
Sets whether to show the bookmarks action in the Android toolbar. Defaults
to true.
final
- androidShowDocumentInfoView → bool?
-
Sets whether to show the document info view in the Android toolbar.
Defaults to true.
final
- androidShowOutlineAction → bool?
-
Sets whether to show the outline action in the Android toolbar. Defaults
to true.
final
- androidShowPrintAction → bool?
-
Sets whether to show the print action in the Android toolbar.
Defaults to true.
final
- androidShowSearchAction → bool?
-
Sets whether to show the search action in the Android toolbar. Defaults
to true.
final
-
Sets whether to show the share action in the Android toolbar. Defaults
to true.
final
- androidShowThumbnailGridAction → bool?
-
Sets whether to show the thumbnail grid action in the Android toolbar.
Defaults to true.
final
- annotationMenuConfiguration → AnnotationMenuConfiguration?
-
Configuration for annotation contextual menu customization.
final
- annotationToolsGrouping → List?
-
final
- appearanceMode → AppearanceMode?
-
Sets the appearance mode. Defaults to defaultMode.
final
- defaultZoomScale → double?
-
Sets the default zoom scale. Defaults to null. On Web, this is the zoom has priority over PdfConfiguration.zoom.
final
- disableAutosave → bool?
-
Disables autosaving. Defaults to false.
final
- documentLabelEnabled → bool?
-
Sets whether to show the document label on top of the document. Defaults to false.
final
-
editableAnnotationTypes
→ List<
String> ? -
Sets the annotation types that are editable. Defaults to null.
final
- enableAnnotationEditing → bool?
-
Annotation, Forms and Bookmark Options
Sets whether to enable annotation editing. Defaults to true.
final
- enableFormEditing → bool?
-
Sets whether to enable form field editing. Defaults to true.
When set to false, form fields (text fields, checkboxes, radio buttons, etc.)
cannot be edited by the user.
final
- enableInstantComments → bool?
-
Sets whether to enable instant comments. Defaults to true. This feature
requires a Instant Synchronization license.
final
- enableMagnifier → bool?
-
Sets whether to enable the measurement magnifier. Defaults to true.
This feature requires a Measurement license.
final
- enableMeasurementTools → bool?
-
final
- enableTextSelection → bool?
-
Enables text selection. Defaults to true.
final
- firstPageAlwaysSingle → bool?
-
Sets whether the first page should be always single in double page mode. Defaults to false.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- immersiveMode → bool?
-
Sets whether to enable immersive mode. Defaults to false.
final
- inlineSearch → bool?
-
User Interface Options
Sets whether to make the search mode inline. Defaults to false.
final
- invertColors → bool?
-
Sets whether to invert the colors of the document. Defaults to false.
final
- iOSAllowToolbarTitleChange → bool?
-
Sets whether to allow the toolbar title to change when the document is
scrolled. Defaults to false.
final
- iOSBookmarkIndicatorInteractionEnabled → bool?
-
Enables/disables the bookmark indicator's interaction on iOS. Defaults to
true. If this is enabled, tapping the indicator will bookmark or un-bookmark the page it is displayed on.final - iOSBookmarkIndicatorMode → IOSBookmarkIndicatorMode?
-
Sets the bookmark indicator mode for iOS. This controls whether a button
indicating the current bookmark status of the page will be displayed on
the page itself. Defaults to
off.final - iOSFileConflictResolution → IOSFileConflictResolution?
-
Sets the file conflict resolution strategy for iOS.
final
-
iOSLeftBarButtonItems
→ List<
String> ? -
Sets the left bar button items for the iOS toolbar.
final
-
iOSRightBarButtonItems
→ List<
String> ? -
Sets the right bar button items for the iOS toolbar.
final
- maximumZoomScale → double?
-
Sets the maximum zoom scale. Defaults to null.
final
- measurementSnappingEnabled → bool?
-
Sets whether to enable measurement snapping. Defaults to true.
This feature requires a Measurement license.
final
-
measurementValueConfigurations
→ List<
MeasurementValueConfiguration> ? -
Sets the measurement configuration. Defaults to null.
This feature requires a Measurement license.
See
MeasurementConfigurationfor more information.final - minimumZoomScale → double?
-
Sets the minimum zoom scale. Defaults to null.
final
- pageLayoutMode → PageLayoutMode?
-
Document Presentation Options
final
- pageTransition → PageTransition?
-
Sets the page transition mode. This is only applicable to continuous scroll modes.
final
- password → String?
-
Sets the password to unlock the document.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollDirection → ScrollDirection?
-
Sets the direction in which pages are laid out horizontally.
This is available only on Android and iOS.
final
-
settingsMenuItems
→ List<
String> ? -
Sets the items to show in the settings menu.
final
-
Sets whether to show the action navigation buttons. Defaults to false.
final
- showPageLabels → bool?
-
Sets whether to show page labels instead of page numbers.
final
- showThumbnailBar → ThumbnailBarMode?
-
Thumbnail Options
Sets the thumbnail bar mode. Defaults to defaultMode.
final
- signatureCreationConfiguration → SignatureCreationConfiguration?
-
final
- signatureSavingStrategy → SignatureSavingStrategy?
-
final
- spreadFitting → SpreadFitting?
-
Sets the spread fitting mode. This is only applicable to double page modes.
final
- startPage → int?
-
Sets the page to start the document with.
final
- themeConfiguration → ThemeConfiguration?
-
Configuration for customizing the viewer's visual theme.
final
-
toolbarMenuItems
→ List<
ToolbarMenuItems> ? -
Sets the toolbar menu items. Defaults to null.
final
- toolbarTitle → String?
-
Sets the title of the toolbar.
final
- userInterfaceViewMode → UserInterfaceViewMode?
-
Sets the user interface view mode. Defaults to automatic.
final
- webConfiguration → PdfWebConfiguration?
-
Sets the web specific configuration. This is only applicable to web.
If not set, the default web configuration will be used.
final
Methods
-
convertAnnotationToolsGrouping(
) → dynamic -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Returns a Map representation of the PdfConfiguration object. This is used to pass the configuration to the platform side.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited