enableFormEditing property

bool? enableFormEditing
final

Sets whether to enable form field editing. Defaults to true. When set to false, form fields (text fields, checkboxes, radio buttons, etc.) cannot be edited by the user.

Platform behavior:

  • Android: Uses a separate formEditingEnabled API, so form editing can be controlled independently from annotation editing.
  • iOS: Forms are implemented as widget annotations. When enableAnnotationEditing is set to false, all annotations including forms are disabled by default. However, setting enableFormEditing: true will re-enable form editing even when annotation editing is disabled.

Behavior matrix:

enableAnnotationEditing enableFormEditing Result
true (or not set) true (or not set) All annotations and forms editable
true (or not set) false Annotations editable, forms NOT editable
false true Forms editable, other annotations NOT editable
false false (or not set) Nothing editable

Implementation

final bool? enableFormEditing;