save abstract method

Future<bool> save({
  1. String? outputPath,
  2. DocumentSaveOptions? options,
})

Saves the document back to its original location if it has been changed. If there were no changes to the document, the document file will not be modified.

Implementation

Future<bool> save({String? outputPath, DocumentSaveOptions? options});