PdfWebConfiguration class
Copyright © 2024-2026 PSPDFKit GmbH. All rights reserved.
THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE PSPDFKIT LICENSE AGREEMENT. UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES. This notice may not be removed from this file.
This is the Configuration class for flutter web. It is used to group the configuration options for Flutter web.
Constructors
-
PdfWebConfiguration({String? xfdf, bool? xfdfKeepCurrentAnnotations, num? autoCloseThreshold, AutoSaveMode? autoSaveMode, String? baseCoreUrl, String? baseUrl, String? container, List? customFonts, bool? disableHighQualityPrinting, bool? disableMultiSelection, bool? disableOpenParameters, bool? disableWebAssemblyStreaming, List? documentEditorToolbarItems, bool? enableAutomaticLinkExtraction, bool? enableClipboardActions, bool? enableHistory, bool? enableServiceWorkerSupport, List<
String> ? formFieldsNotSavingSignatures, bool? headless, Map<String, dynamic> ? instantJSON, String? locale, num? maxDefaultZoomLevel, num? maxMentionSuggestions, num? maxPasswordRetries, List? mentionableUsers, num? minDefaultZoomLevel, num? overrideMemoryLimit, bool? preventTextCopy, Map<String, dynamic> ? printOptions, bool? restrictAnnotationToPageBounds, String? serverUrl, Map<String, dynamic> ? authPayload, List? stampAnnotationTemplates, num? standaloneInstancesPoolSize, List<String> ? styleSheets, String? theme, ToolbarPlacement? toolbarPlacement, SidebarMode? sidebarMode, bool? formDesignMode, NutrientWebInteractionMode? interactionMode, bool? allowPrinting, bool? canScrollWhileDrawing, bool? keepFirstSpreadAsSinglePage, bool? keepSelectedTool, double? pageSpacing, num? pageRotation, bool? previewRedactionMode, SidebarMode? sideBarMode, ShowSignatureValidationStatusMode? showSignatureValidationStatus, bool? showAnnotationNotes, bool? showAnnotations, num? spreadSpacing, num? viewportPadding, dynamic zoom, double? zoomStep, dynamic customUIConfiguration, dynamic customRenderers, dynamic electronicSignatures, String? documentId, List? editableAnnotationTypes, bool? instant, bool? disableForms, bool? disableTextSelection, List<NutrientWebToolbarItem> ? toolbarItems, NutrientWebAnnotationToolbarItemsCallback? annotationToolbarItems, OfficeConversionSettings? officeConversionSettings})
Properties
- allowPrinting → bool?
-
Whether to allow printing.
final
- annotationToolbarItems → NutrientWebAnnotationToolbarItemsCallback?
-
Annotation toolbar items callback. If not set, the default annotation toolbar items will be used.
final
-
authPayload
→ Map<
String, dynamic> ? -
final
- autoCloseThreshold → num?
-
The threshold for automatically closing the document.
final
- autoSaveMode → AutoSaveMode?
-
The auto-save mode to use.
final
- baseCoreUrl → String?
-
The base URL for the PSPDFKit Core library.
final
- baseUrl → String?
-
The base URL for the PSPDFKit server.
final
- canScrollWhileDrawing → bool?
-
Whether to allow scrolling while drawing.
final
- container → String?
-
The ID of the container element for the viewer.
final
- customFonts → List?
-
An array of custom fonts to load.
final
- customRenderers → dynamic
-
Custom renderers to use.
final
- customUIConfiguration → dynamic
-
Custom UI configuration to use.
final
- disableForms → bool?
-
Whether to disable forms.
final
- disableHighQualityPrinting → bool?
-
Whether to disable high-quality printing.
final
- disableMultiSelection → bool?
-
Whether to disable multi-selection.
final
- disableOpenParameters → bool?
-
Whether to disable open parameters.
final
- disableTextSelection → bool?
-
Whether to disable text selection.
final
- disableWebAssemblyStreaming → bool?
-
Whether to disable WebAssembly streaming.
final
-
An array of items to show in the document editor footer.
final
- documentEditorToolbarItems → List?
-
An array of items to show in the document editor toolbar.
final
- documentId → String?
-
The ID of the document to load.
final
- editableAnnotationTypes → List?
-
An array of editable annotation types.
final
- electronicSignatures → dynamic
-
Electronic signatures configuration to use.
final
- enableAutomaticLinkExtraction → bool?
-
Whether to enable automatic link extraction.
final
- enableClipboardActions → bool?
-
Whether to enable clipboard actions.
final
- enableHistory → bool?
-
Whether to enable history.
final
- enableServiceWorkerSupport → bool?
-
Whether to enable service worker support.
final
- formDesignMode → bool?
-
Whether to enable form design mode.
final
-
formFieldsNotSavingSignatures
→ List<
String> ? -
An array of form fields that should not save signatures.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headless → bool?
-
Whether to run in headless mode.
final
- instant → bool?
-
Whether to run in instant mode (server only).
final
-
instantJSON
→ Map<
String, dynamic> ? -
The JSON configuration for instant mode (server only).
final
- interactionMode → NutrientWebInteractionMode?
-
The interaction mode to use.
final
- keepFirstSpreadAsSinglePage → bool?
-
Whether to keep the first spread as a single page.
final
- keepSelectedTool → bool?
-
Whether to keep the selected tool.
final
- locale → String?
-
The locale to use.
final
- maxDefaultZoomLevel → num?
-
The maximum default zoom level.
final
- maxMentionSuggestions → num?
-
The maximum number of mention suggestions to show.
final
- maxPasswordRetries → num?
-
The maximum number of password retries.
final
- mentionableUsers → List?
-
An array of mentionable users.
final
- minDefaultZoomLevel → num?
-
The minimum default zoom level.
final
- officeConversionSettings → OfficeConversionSettings?
-
Office conversion settings for documents like .docx, .xlsx, .pptx.
final
- overrideMemoryLimit → num?
-
The memory limit to override.
final
- pageRotation → num?
-
The rotation of the page.
final
- pageSpacing → double?
-
The spacing between pages.
final
- preventTextCopy → bool?
-
Whether to prevent text copy.
final
- previewRedactionMode → bool?
-
Whether to preview redaction mode.
final
-
printOptions
→ Map<
String, dynamic> ? -
The print options to use.
final
- restrictAnnotationToPageBounds → bool?
-
Whether to restrict annotations to page bounds.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serverUrl → String?
-
The URL of the PSPDFKit server (server only).
final
- showAnnotationNotes → bool?
-
Whether to show annotation notes.
final
- showAnnotations → bool?
-
Whether to show annotations.
final
- showSignatureValidationStatus → ShowSignatureValidationStatusMode?
-
The mode for showing signature validation status.
final
- sideBarMode → SidebarMode?
-
The sidebar mode to use.
final
-
The sidebar mode to use.
final
- spreadSpacing → num?
-
The spacing between spreads.
final
- stampAnnotationTemplates → List?
-
An array of stamp annotation templates.
final
- standaloneInstancesPoolSize → num?
-
The size of the standalone instances pool.
final
-
styleSheets
→ List<
String> ? -
An array of style sheets to load.
final
- theme → String?
-
The theme to use.
final
-
toolbarItems
→ List<
NutrientWebToolbarItem> ? -
Main toolbar items. If not set, the default toolbar items will be used.
final
- toolbarPlacement → ToolbarPlacement?
-
The toolbar placement to use.
final
- viewportPadding → num?
-
The viewport padding to use.
final
- xfdf → String?
-
The XFDF string to load into the document.
final
- xfdfKeepCurrentAnnotations → bool?
-
Whether to keep the current annotations when loading XFDF.
final
- zoom → dynamic
-
The zoom level to use.
final
- zoomStep → double?
-
The zoom step to use.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited