PspdfkitWidget class

A widget that displays a PDF document using Nutrient.

@deprecated Use NutrientView instead.

Inheritance
Annotations

Constructors

PspdfkitWidget({Key? key, required String documentPath, dynamic configuration, PspdfkitWidgetCreatedCallback? onPspdfkitWidgetCreated, PdfDocumentLoadedCallback? onPdfDocumentLoaded, PdfDocumentLoadFailedCallback? onPdfDocumentError, PageChangedCallback? onPageChanged, PageClickedCallback? onPageClicked, PdfDocumentSavedCallback? onPdfDocumentSaved, List<CustomToolbarItem> customToolbarItems = const [], OnCustomToolbarItemTappedCallback? onCustomToolbarItemTapped})
Creates a new PspdfkitWidget widget.
const

Properties

configuration → dynamic
The configuration to use for the document.
final
customToolbarItems List<CustomToolbarItem>
Custom toolbar items to add to the toolbar.
final
documentPath String
The path to the document to display.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onCustomToolbarItemTapped OnCustomToolbarItemTappedCallback?
Called when a custom toolbar item is tapped.
final
onPageChanged PageChangedCallback?
Called when the page changes.
final
onPageClicked PageClickedCallback?
Called when a page is clicked.
final
onPdfDocumentError OnCustomToolbarItemTappedCallback?
Called when the document fails to load.
final
onPdfDocumentLoaded PdfDocumentLoadedCallback?
Called when the document is loaded.
final
onPdfDocumentSaved PdfDocumentSavedCallback?
Called when the document is saved.
final
onPspdfkitWidgetCreated PspdfkitWidgetCreatedCallback?
Called when the widget is created.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<PspdfkitWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited