StampAnnotation class

Stamp annotation

Inheritance
Available extensions

Constructors

StampAnnotation({String? id, required List<double> bbox, String? createdAt, String? creatorName, required StampType stampType, String? attachment, double rotation = 0.0, String? title, Color? color, String? subtitle, required int pageIndex, double opacity = 1.0, int? pdfObjectId, List<AnnotationFlag>? flags, String? updatedAt, String? name, String? subject, bool hidden = false, Map<String, dynamic>? customData})
StampAnnotation.fromJson(Map<String, dynamic> json)
factory

Properties

attachment String?
final
bbox List<double>
finalinherited
color Color?
final
createdAt String?
finalinherited
creatorName String?
finalinherited
customData Map<String, dynamic>?
finalinherited
flags List<AnnotationFlag>?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
hidden bool
finalinherited
id String?
finalinherited
name String?
finalinherited
opacity double
finalinherited
pageIndex int
finalinherited
pdfObjectId int?
finalinherited
rotation double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stampType StampType
final
subject String?
finalinherited
subtitle String?
final
title String?
final
type AnnotationType
finalinherited
updatedAt String?
finalinherited
v int
finalinherited

Methods

copyWith({String? id, List<double>? bbox, String? createdAt, int? pageIndex, String? title, String? name, StampType? stampType, Color? color, String? creatorName, double? opacity, int? pdfObjectId, List<AnnotationFlag>? flags, String? updatedAt, String? subject, bool? hidden}) StampAnnotation

Available on StampAnnotation, provided by the StampAnnotationExtensions extension

Creates a copy of this annotation with the given fields replaced with the new values
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited