SubmitFormAction class

Action to submit form data to a URL

Inheritance

Constructors

SubmitFormAction({required String url, List<String>? flags, Action? subAction})
SubmitFormAction.fromJson(Map<String, dynamic> json)
factory

Properties

flags List<String>?
Optional flags that control how the form data is submitted
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subAction Action?
Optional sub-action that will be executed after this action
finalinherited
url String
The URL to submit the form data to
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited