ToolbarPosition enum

Defines the position of toolbar items.

Inheritance
Available extensions

Values

primary → const ToolbarPosition

Primary position, typically visible in the main toolbar.

secondary → const ToolbarPosition

Secondary position, may be in overflow menu.

iosLeft → const ToolbarPosition

For iOS, represents the navigation bar left (leading) position.

iosRight → const ToolbarPosition

For iOS, represents the navigation bar right (trailing) position.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ToolbarPosition>
A constant List of the values in this enum, in order of their declaration.