AppearanceMode enum

An enum representing the appearance mode options for PSPDFKit.

The options are:

  • defaultMode: The default appearance mode.
  • sepia: The sepia appearance mode.
  • night: The dark appearance mode.
  • allCustomColors: The appearance mode with all custom colors.
Inheritance
Available extensions

Values

defaultMode → const AppearanceMode
sepia → const AppearanceMode
night → const AppearanceMode
allCustomColors → const AppearanceMode

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
name String?

Available on AppearanceMode, provided by the WebAppearanceMode extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
webName String?

Available on AppearanceMode, provided by the WebAppearanceMode extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AppearanceMode>
A constant List of the values in this enum, in order of their declaration.