darkThemeResource property
Name of the Android XML theme resource to use for the dark colour scheme.
The string must match a theme declared in your Android app's res/values/
directory. This theme is applied when appearanceMode (or
NutrientViewConfiguration.appearanceMode) is set to AppearanceMode.night.
Example: 'MyApp_Dark' — the theme must extend one of the Nutrient SDK
base themes.
Maps to PdfActivityConfiguration$Builder.darkTheme(int) (resolved by
Resources.getIdentifier).
Implementation
final String? darkThemeResource;