Annotation class abstract

Base class for all Nutrient annotations

Available extensions

Constructors

Annotation({String? id, required AnnotationType type, required List<double> bbox, required int pageIndex, String? creatorName, String? createdAt, double opacity = 1.0, int? pdfObjectId, List<AnnotationFlag>? flags, String? updatedAt, String? name, String? subject, bool hidden = false, Map<String, dynamic>? customData})
Annotation.fromJson(Map<String, dynamic> json, [Map<String, dynamic>? attachments])
factory

Properties

bbox List<double>
final
createdAt String?
final
creatorName String?
final
customData Map<String, dynamic>?
final
flags List<AnnotationFlag>?
final
hashCode int
The hash code for this object.
no setterinherited
hidden bool
final
id String?
final
name String?
final
opacity double
final
pageIndex int
final
pdfObjectId int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subject String?
final
type AnnotationType
final
updatedAt String?
final
v int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

tryFromJson(Map<String, dynamic> json, [Map<String, dynamic>? attachments]) Annotation?
Defensive variant of Annotation.fromJson for the bindings/typed layer.