AnnotationPropertiesGetters extension
Extension for convenient getters on AnnotationProperties.
Properties
-
bbox
→ List<
double> ? -
Available on AnnotationProperties, provided by the AnnotationPropertiesGetters extension
Gets the bounding box as a list of doublesx, y, width, height. Decodes from the internal JSON string representation.no setter - boundingBox → Rect?
-
Available on AnnotationProperties, provided by the AnnotationPropertiesGetters extension
Gets the bounding box as a Flutter Rect object. Decodes from the internal JSON string representation.no setter - color → Color?
-
Available on AnnotationProperties, provided by the AnnotationPropertiesGetters extension
Gets the stroke color as a Flutter Color object.no setter -
customData
→ Map<
String, Object?> ? -
Available on AnnotationProperties, provided by the AnnotationPropertiesGetters extension
Gets the custom data as a typed Map. Decodes from the internal JSON string representation.no setter - fillColorValue → Color?
-
Available on AnnotationProperties, provided by the AnnotationPropertiesGetters extension
Gets the fill color as a Flutter Color object.no setter -
flags
→ List<
String> ? -
Available on AnnotationProperties, provided by the AnnotationPropertiesGetters extension
Gets the flags as a list of strings. Decodes from the internal JSON string representation.no setter -
flagsSet
→ Set<
AnnotationFlag> ? -
Available on AnnotationProperties, provided by the AnnotationPropertiesGetters extension
Gets the flags as a Set of AnnotationFlag enums. Decodes from the internal JSON string representation. Skips any flag names that don't match a valid AnnotationFlag value (e.g., Web SDK may return 'noPrint' which maps to the 'print' flag).no setter -
inkLines
→ List<
List< ?List< >double> > -
Available on AnnotationProperties, provided by the AnnotationPropertiesGetters extension
Gets the ink lines as a typed nested list. Decodes from the internal JSON string representation. Format: [[x, y, pressure, ...], ...]no setter