BookmarkExtensions extension

Extension methods for the Bookmark class to provide convenience constructors and utility methods.

on

Properties

pageIndex int?

Available on Bookmark, provided by the BookmarkExtensions extension

Returns the page index this bookmark points to.
no setter

Methods

copyWith({String? pdfBookmarkId, String? name, String? actionJson}) Bookmark

Available on Bookmark, provided by the BookmarkExtensions extension

Creates a copy of this bookmark with the specified fields replaced.
isForPage(int pageIndex) bool

Available on Bookmark, provided by the BookmarkExtensions extension

Returns true if this bookmark points to the specified page.
toInstantJson() Map<String, dynamic>

Available on Bookmark, provided by the BookmarkExtensions extension

Converts this bookmark to Instant JSON format.