BookmarkManagerInterface class abstract
Abstract interface for bookmark operations on a PDF document.
Concrete implementations are provided by each platform package:
BookmarkManagerAndroidinnutrient_flutter_androidBookmarkManagerIOSinnutrient_flutter_iosBookmarkManagerWebinnutrient_flutter_web
Access via NutrientDocumentInterface.bookmarks or
NutrientController.document.bookmarks.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addBookmark(
Bookmark bookmark) → Future< Bookmark> -
Adds
bookmarkto the document and returns the saved bookmark (which may have a platform-assigned Bookmark.pdfBookmarkId). -
getBookmarks(
) → Future< List< Bookmark> > - Returns all bookmarks in the document.
-
getBookmarksForPage(
int pageIndex) → Future< List< Bookmark> > -
Returns all bookmarks that target
pageIndex. -
hasBookmarkForPage(
int pageIndex) → Future< bool> -
Returns
trueif there is at least one bookmark targetingpageIndex. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeBookmark(
Bookmark bookmark) → Future< bool> -
Removes
bookmarkfrom the document. -
toString(
) → String -
A string representation of this object.
inherited
-
updateBookmark(
Bookmark bookmark) → Future< bool> -
Updates
bookmarkin the document.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited