DocumentLoadedEvent class final
Emitted when a document is fully loaded and ready for interaction.
On Android and iOS this fires from the native document listener after the
document object is available. On Web it fires at the end of
onInstanceLoaded() since the document is already loaded at that point.
- Inheritance
-
- Object
- NutrientEvent
- DocumentLoadedEvent
Constructors
- DocumentLoadedEvent(NutrientDocumentInterface document)
-
const
Properties
- document → NutrientDocumentInterface
-
The document that finished loading.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited