DocumentPathResolver class
Utility class to resolve document paths for native platforms.
Handles different path formats:
- Asset paths (assets/...)
- File paths (file://...)
- Content URIs (content://...)
- Remote URLs (https://...)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearAll(
) → Future< void> - Clears all cached paths.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
release(
String cacheKey) → Future< void> - Releases a cached resolved path.
-
resolve(
String documentPath, {String? cacheKey}) → Future< String> - Resolves a document path to a native-accessible path.
-
resolveBytes(
Uint8List bytes, {required String cacheKey}) → Future< String> -
Writes in-memory document
bytesto a temporary file and returns its path. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → DocumentPathResolver
-
final