FormFieldUpdatedEvent class final

Emitted when a form field value changes.

formFieldJson is a JSON string describing the updated form field, consistent with FormManagerInterface.getFormFieldJson.

Inheritance

Constructors

FormFieldUpdatedEvent(String formFieldJson)
const

Properties

formField PdfFormField?
The typed form field for this event, or null if it couldn't be parsed.
no setter
formFieldJson String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited