FormManagerInterface class abstract
Abstract interface for form field operations on a PDF document.
Concrete implementations are provided by each platform package:
FormManagerAndroidinnutrient_flutter_androidFormManagerIOSinnutrient_flutter_iosFormManagerWebinnutrient_flutter_web
Access via controller.document.forms.
Customising Behaviour
Override the form manager in your document subclass:
class MyDocument extends NutrientDocumentAndroid {
@override
FormManagerInterface createFormManager() => MyFormManager(this);
}
class MyFormManager extends FormManagerAndroid {
@override
Future<String?> getFormFieldValue(String fqn) async {
// custom logic
return super.getFormFieldValue(fqn);
}
}
- Available extensions
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getFormField(
String fieldName) → Future< PdfFormField?> -
Available on FormManagerInterface, provided by the FormManagerTyped extension
Returns the typed form field namedfieldName, ornullif not found or of an unrecognized type. -
getFormFieldJson(
String fieldName) → Future< String> -
Returns a JSON string for the form field identified by
fieldName. -
getFormFields(
) → Future< List< PdfFormField> > -
Available on FormManagerInterface, provided by the FormManagerTyped extension
Returns all form fields in the document as typed PdfFormFields. -
getFormFieldsJson(
) → Future< String> - Returns a JSON string of all form fields in the document.
-
getFormFieldValue(
String fullyQualifiedName) → Future< String?> -
Returns the value of the form field identified by
fullyQualifiedName, ornullif not found. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setFormFieldValue(
String value, String fullyQualifiedName) → Future< bool> -
Sets the value of the form field identified by
fullyQualifiedName. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited