bookmarkIndicatorInteractionEnabled property
Whether tapping the bookmark indicator toggles the bookmark on the page.
When true, tapping the bookmark indicator adds or removes a bookmark for
that page. When false, the indicator is read-only (informational only).
Only meaningful when bookmarkIndicatorMode is not IOSBookmarkIndicatorMode.off.
Maps to PSPDFConfigurationBuilder.bookmarkIndicatorInteractionEnabled.
Implementation
final bool? bookmarkIndicatorInteractionEnabled;