documentLabelEnabled property
Show the document title overlay at the top of the viewer.
When true, the PDF document title (from the document metadata) is shown
as an overlay at the top of the screen.
Maps to PSPDFConfigurationBuilder.documentLabelEnabled.
Implementation
final bool? documentLabelEnabled;