InkAnnotationProperties extension
Extension for ink annotation property updates.
Methods
-
withInkLines(
List< List< lines) → AnnotationPropertiesOffset> > -
Available on AnnotationProperties, provided by the InkAnnotationProperties extension
Creates a modified copy with updated ink lines. Accepts a list of lines where each line is a list of Offset points. Points are converted tox, y, pressureformat with default pressure of 1.0. -
withRawInkLines(
List< List< inkLines) → AnnotationPropertiesList< >double> > -
Available on AnnotationProperties, provided by the InkAnnotationProperties extension
Creates a modified copy with updated raw ink lines. Accepts ink lines in the native format: [[x, y, pressure, ...], ...]