InstantSyncFailedEvent class final
Emitted when an Instant document sync fails.
- Inheritance
-
- Object
- NutrientEvent
- InstantSyncFailedEvent
Constructors
- InstantSyncFailedEvent(String documentId, String error)
-
const
Properties
- documentId → String
-
final
- error → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited