LinkAnnotation class

Link annotation

Inheritance
Available extensions

Constructors

LinkAnnotation({String? id, required Action action, required List<double> bbox, String? createdAt, required int pageIndex, String? note, BorderStyle? borderStyle, double? borderWidth, Color? borderColor, String? creatorName, double opacity = 1.0, int? pdfObjectId, List<AnnotationFlag>? flags, String? updatedAt, String? name, String? subject, bool hidden = false, Map<String, dynamic>? customData})
LinkAnnotation.fromJson(Map<String, dynamic> json)
factory

Properties

action Action
final
bbox List<double>
finalinherited
borderColor Color?
final
borderStyle BorderStyle?
final
borderWidth double?
final
createdAt String?
finalinherited
creatorName String?
finalinherited
customData Map<String, dynamic>?
finalinherited
flags List<AnnotationFlag>?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
hidden bool
finalinherited
id String?
finalinherited
name String?
finalinherited
note String?
final
opacity double
finalinherited
pageIndex int
finalinherited
pdfObjectId int?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subject String?
finalinherited
type AnnotationType
finalinherited
updatedAt String?
finalinherited
v int
finalinherited

Methods

copyWith({String? id, List<double>? bbox, String? createdAt, int? pageIndex, Action? action, String? note, BorderStyle? borderStyle, double? borderWidth, Color? borderColor, String? creatorName, double? opacity, int? pdfObjectId, List<AnnotationFlag>? flags, String? updatedAt, String? name, String? subject, bool? hidden}) LinkAnnotation

Available on LinkAnnotation, provided by the LinkAnnotationExtensions extension

Creates a copy of this annotation with the given fields replaced with the new values
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited