currentLicenseKey property
String?
get
currentLicenseKey
Get the license key for the current platform.
Returns the appropriate license key based on the current platform.
Returns null if SDK not initialized or no key for current platform.
Implementation
static String? get currentLicenseKey {
if (!_initialized) return null;
switch (defaultTargetPlatform) {
case TargetPlatform.android:
return _androidLicenseKey;
case TargetPlatform.iOS:
return _iosLicenseKey;
case TargetPlatform.linux:
case TargetPlatform.macOS:
case TargetPlatform.windows:
case TargetPlatform.fuchsia:
// Web is handled by kIsWeb check
return _webLicenseKey;
}
}