exitAnnotationCreationMode abstract method
Exits annotation creation mode and returns to normal viewer interaction.
Returns true if the mode was exited, false if the request was
rejected, or null if the platform does not report a result.
Implementation
Future<bool?> exitAnnotationCreationMode();