onControllerReady property
void Function(T controller)?
onControllerReady
final
Called when the typed controller is ready for use.
The controller is the registered platform adapter — it implements
T. Fires after the platform view is created, the document has
loaded, and NutrientController.markReady has been called.
Implementation
final void Function(T controller)? onControllerReady;