enableInstantComments property
Enable Instant comments. Defaults to false.
When true, the comment creation menu items are exposed in the viewer's
long-press and text-selection menus (iOS) and the comment marker tool is
added to the annotation creation toolbar (Android). Has no effect on
non-Instant documents and requires the Instant Comments component in
your server license.
Implementation
final bool? enableInstantComments;