spreadsheetMaximumContentWidthPerSheet property
Maximum width (in millimeters) for spreadsheet content per sheet.
This setting controls the maximum width of content that will be rendered for each sheet in Excel spreadsheets. Content exceeding this width will be truncated. The default value is platform-specific.
Implementation
final num? spreadsheetMaximumContentWidthPerSheet;