PageClickedEvent class final
Emitted when the user taps on a page.
pageIndex is zero-based. point is the tap location in PDF-space
coordinates (logical points from the page origin), or null if the
platform does not provide coordinate information. annotationJson is the
Instant JSON string of the tapped annotation, or null if the tap did not
hit an annotation.
- Inheritance
-
- Object
- NutrientEvent
- PageClickedEvent
Constructors
- PageClickedEvent(int pageIndex, {Offset? point, String? annotationJson})
-
const
Properties
- annotation → Annotation?
-
The typed annotation that was tapped, or
nullif the tap missed an annotation (or the payload couldn't be parsed).no setter - annotationJson → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- pageIndex → int
-
final
- point → Offset?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited