RedactionAnnotation class

Redaction annotation

Inheritance
Available extensions

Constructors

RedactionAnnotation({String? id, required List<List<double>> rects, String? createdAt, String? creatorName, Color? fillColor, String? overlayText, double? fontSize, Color? fontColor, String? repeat, required int pageIndex, double opacity = 1.0, int? pdfObjectId, List<AnnotationFlag>? flags, String? updatedAt, String? name, String? subject, bool hidden = false, Color? outlineColor, bool? repeatOverlayText, double rotation = 0.0, Map<String, dynamic>? customData})
RedactionAnnotation.fromJson(Map<String, dynamic> json)
factory

Properties

bbox List<double>
finalinherited
createdAt String?
finalinherited
creatorName String?
finalinherited
customData Map<String, dynamic>?
finalinherited
fillColor Color?
final
flags List<AnnotationFlag>?
finalinherited
fontColor Color?
final
fontSize double?
final
hashCode int
The hash code for this object.
no setterinherited
hidden bool
finalinherited
id String?
finalinherited
name String?
finalinherited
opacity double
finalinherited
outlineColor Color?
final
overlayText String?
final
pageIndex int
finalinherited
pdfObjectId int?
finalinherited
rects List<List<double>>
final
repeat String?
final
repeatOverlayText bool?
final
rotation double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subject String?
finalinherited
type AnnotationType
finalinherited
updatedAt String?
finalinherited
v int
finalinherited

Methods

copyWith({String? id, List<List<double>>? rects, String? createdAt, int? pageIndex, Color? fillColor, String? overlayText, double? fontSize, Color? fontColor, String? repeat, Color? outlineColor, bool? repeatOverlayText, double? rotation, String? creatorName, double? opacity, int? pdfObjectId, List<AnnotationFlag>? flags, String? updatedAt, String? name, String? subject, bool? hidden}) RedactionAnnotation

Available on RedactionAnnotation, provided by the RedactionAnnotationExtensions extension

Creates a copy of this annotation with the given fields replaced with the new values
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited