RichMediaAnnotation class

Rich media annotation

Inheritance
Mixed-in types
Available extensions

Constructors

RichMediaAnnotation({String? id, required List<double> bbox, String? createdAt, String? creatorName, String? contentType, String? fileName, String? description, required String mediaAttachmentId, String mediaSource = 'richMedia', Map<String, dynamic>? encoding, String? mediaType, String? source, Map<String, dynamic>? params, AnnotationAttachment? attachment, required int pageIndex, double opacity = 1.0, int? pdfObjectId, List<AnnotationFlag>? flags, String? updatedAt, String? name, String? subject, bool hidden = false, Map<String, dynamic>? customData})
RichMediaAnnotation.fromJson(Map<String, dynamic> json, [Map<String, dynamic>? attachments])
factory

Properties

attachment AnnotationAttachment?
The attachment associated with this annotation
final
bbox List<double>
finalinherited
contentType String?
final
createdAt String?
finalinherited
creatorName String?
finalinherited
customData Map<String, dynamic>?
finalinherited
description String?
final
encoding Map<String, dynamic>?
final
fileName String?
final
flags List<AnnotationFlag>?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
hidden bool
finalinherited
id String?
finalinherited
mediaAttachmentId String
final
mediaSource String
final
mediaType String?
final
name String?
finalinherited
opacity double
finalinherited
pageIndex int
finalinherited
params Map<String, dynamic>?
final
pdfObjectId int?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String?
final
subject String?
finalinherited
type AnnotationType
finalinherited
updatedAt String?
finalinherited
v int
finalinherited

Methods

copyWith({String? id, List<double>? bbox, String? createdAt, int? pageIndex, String? contentType, String? fileName, String? description, String? mediaAttachmentId, String? mediaSource, Map<String, dynamic>? encoding, String? mediaType, String? source, Map<String, dynamic>? params, AnnotationAttachment? attachment, String? creatorName, double? opacity, int? pdfObjectId, List<AnnotationFlag>? flags, String? updatedAt, String? name, String? subject, bool? hidden}) RichMediaAnnotation

Available on RichMediaAnnotation, provided by the RichMediaAnnotationExtensions extension

Creates a copy of this annotation with the given fields replaced with the new values
createAttachmentFromJson(String attachmentId, Map<String, dynamic>? attachments) AnnotationAttachment?
Creates an attachment from JSON data
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited