ScreenAnnotation class
Screen annotation
- Inheritance
-
- Object
- Annotation
- ScreenAnnotation
- Available extensions
Constructors
-
ScreenAnnotation({String? id, required List<
double> bbox, String? createdAt, String? creatorName, required String mediaType, required String source, bool? autoplay, bool? showControls, required int pageIndex, double opacity = 1.0, int? pdfObjectId, List<AnnotationFlag> ? flags, String? updatedAt, String? name, String? subject, Map<String, dynamic> ? customData}) -
ScreenAnnotation.fromJson(Map<
String, dynamic> json) -
factory
Properties
- autoplay → bool?
-
final
-
bbox
→ List<
double> -
finalinherited
- createdAt → String?
-
finalinherited
- creatorName → String?
-
finalinherited
-
customData
→ Map<
String, dynamic> ? -
finalinherited
-
flags
→ List<
AnnotationFlag> ? -
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
finalinherited
- id → String?
-
finalinherited
- mediaType → String
-
final
- name → String?
-
finalinherited
- opacity → double
-
finalinherited
- pageIndex → int
-
finalinherited
- pdfObjectId → int?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showControls → bool?
-
final
- source → String
-
final
- subject → String?
-
finalinherited
- type → AnnotationType
-
finalinherited
- updatedAt → String?
-
finalinherited
- v → int
-
finalinherited
Methods
-
copyWith(
{String? id, List< double> ? bbox, String? createdAt, int? pageIndex, String? mediaType, String? source, bool? autoplay, bool? showControls, String? creatorName, double? opacity, int? pdfObjectId, List<AnnotationFlag> ? flags, String? updatedAt, String? name, String? subject, }) → ScreenAnnotation -
Available on ScreenAnnotation, provided by the ScreenAnnotationExtensions extension
Creates a copy of this annotation with the given fields replaced with the new values -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited