ShapeAnnotation class abstract

Shape annotation base class for square, circle, and polygon annotations

Inheritance
Available extensions

Constructors

ShapeAnnotation({String? id, required Color? strokeColor, required double? strokeWidth, required List<double> bbox, String? createdAt, required int pageIndex, required AnnotationType type, Color? fillColor, BorderStyle? borderStyle, List<double>? borderDashArray, double? cloudyBorderIntensity, List<double>? cloudyBorderInset, String? note, MeasurementScale? measurementScale, MeasurementPrecision? measurementPrecision, List<double>? measurementBBox, String? creatorName, double opacity = 1.0, int? pdfObjectId, List<AnnotationFlag>? flags, String? updatedAt, String? name, String? subject, bool hidden = false, Map<String, dynamic>? customData})

Properties

bbox List<double>
finalinherited
borderDashArray List<double>?
final
borderStyle BorderStyle?
final
cloudyBorderInset List<double>?
final
cloudyBorderIntensity double?
final
createdAt String?
finalinherited
creatorName String?
finalinherited
customData Map<String, dynamic>?
finalinherited
fillColor Color?
final
flags List<AnnotationFlag>?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
hidden bool
finalinherited
id String?
finalinherited
measurementBBox List<double>?
final
measurementPrecision MeasurementPrecision?
final
measurementScale MeasurementScale?
final
name String?
finalinherited
note String?
final
opacity double
finalinherited
pageIndex int
finalinherited
pdfObjectId int?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strokeColor Color?
final
strokeWidth double?
final
subject String?
finalinherited
type AnnotationType
finalinherited
updatedAt String?
finalinherited
v int
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited