SignatureColorOptions class
The set of color presets offered in the signature creation UI.
Constructors
- SignatureColorOptions({required SignatureColorPreset option1, required SignatureColorPreset option2, required SignatureColorPreset option3})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- option1 → SignatureColorPreset
-
final
- option2 → SignatureColorPreset
-
final
- option3 → SignatureColorPreset
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited