SignatureSavingStrategy enum
When the signature creation UI offers to save a newly created signature.
- neverSave: Never save the signature.
- alwaysSave: Always save the signature.
- saveIfSelected: Save the signature only if the user selects the option.
Supported on Android and iOS. On Web, signature storage is app-managed (via the Web SDK's stored-signatures API), so this option is ignored.
Values
- neverSave → const SignatureSavingStrategy
- alwaysSave → const SignatureSavingStrategy
- saveIfSelected → const SignatureSavingStrategy
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SignatureSavingStrategy> - A constant List of the values in this enum, in order of their declaration.