TextSelectionChangedEvent class final

Emitted when the user's text selection changes.

selectedText is the currently selected string, or null if the selection was cleared.

Inheritance

Constructors

TextSelectionChangedEvent(String? selectedText)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedText String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited