itemsToDisable property
List of default annotation menu actions to disable (show as grayed out).
These actions will appear in the menu but will be non-interactive. Use this when you want to show functionality exists but is temporarily unavailable.
Example: Disable copy action for certain annotation types
itemsToDisable: [AnnotationMenuAction.copy]
Implementation
List<AnnotationMenuAction> itemsToDisable;