IOSAdapter class
Stub for IOSAdapter on web platform.
This class is never instantiated on web - it exists only for API compatibility.
- Inheritance
-
- Object
- NutrientPlatformAdapter
- IOSAdapter
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- platform → TargetPlatform
-
Platform this adapter supports.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → Future< void> -
Dispose of this adapter and clean up resources.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onPlatformViewCreated(
NutrientViewHandle handle) → Future< void> -
Called when the platform view is created.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited