appearanceMode property
The colour theme / appearance mode of the viewer.
On Android maps to PdfActivityConfiguration$Builder.themeMode.
On Web maps to the theme load option (DARK / LIGHT / AUTO).
On iOS appearance is applied through the platform adapter, not the
configuration builder.
Implementation
final AppearanceMode? appearanceMode;