SelectionTheme class
Configuration for customizing text and annotation selection appearance.
Constructors
- SelectionTheme({Color? textHighlightColor, Color? textHandleColor, Color? annotationBorderColor})
-
const
Properties
- annotationBorderColor → Color?
-
Color for the annotation selection border.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textHandleColor → Color?
-
Color for text selection handles. Android only.
final
- textHighlightColor → Color?
-
Color used to highlight selected text.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited